function varargout = ad751(varargin)
% Finds the density of parallel even spaced lines in an image
%
% Uses FFT to calculate the density of laid lines in paper structures.
% Topic: History of paper
%
% Syntax:
% At Matlab prompt type <ad751> with no arguments.
%
% ---
%
% Vlad Atanasiu - 01/01/2002
% Last revision > 11/10/2005
%
% atanasiu@excite.com
% Language & Calligraphy:
% http://mywebpage.netscape.com/atanasiuvlad/ad751/

% ------------------------------------------------------------
% INITIALISE GUI
% ------------------------------------------------------------

if nargin == 0  % LAUNCH GUI
    colordef white;
	% Generate a structure of handles to pass to callbacks, and store it. 
    global fig handles;
    fig = openfig(mfilename,'reuse');
	handles = guihandles(fig);
	guidata(fig, handles);
        
    if nargout > 0
		varargout{1} = fig;
	end
elseif ischar(varargin{1}) % INVOKE NAMED SUBFUNCTION OR CALLBACK
	try
		if (nargout)
			[varargout{1:nargout}] = feval(varargin{:}); % FEVAL switchyard
		else
			feval(varargin{:}); % FEVAL switchyard
		end
	catch
		disp(lasterr);
	end
end

% ------------------------------------------------------------
% GET IMAGE
% ------------------------------------------------------------

% Load files
function varargout = analyse_pushbutton_Callback(hObject, eventdata, handles, varargin)
global BatchList;

% remember starting time of analysis
startTime = clock;

% get item selected in file windows
if isempty(get(handles.Path_text,'String')) == 1
    File_pushbutton_Callback(hObject, eventdata, handles, varargin);
end
InFileFullName = get(handles.Path_text,'String');
[path,name,ext,ver] = fileparts(InFileFullName);

% get active language
global language;
language = get(handles.Language_popupmenu,'String');
languageIndex = get(handles.Language_popupmenu,'Value');
language = cell2mat(language(languageIndex));

% load single file
if get(handles.Varia_BatchOn_checkbox,'Value') == 0
    imgNature = 'single image';
    InNameBatch = InFileFullName;
else
% batch file with multiple images
	imgNature = 'batch images';
    if isempty(BatchList) == 1
        InNameBatch = dir;
        InNameBatch = InNameBatch(3:size(InNameBatch));
    else
        InNameBatch = BatchList;
    end
end

% get type of directory separator
if ispc
    dirsep = '\';
else
    dirsep = '/';
end

% initialisation
measureUnity = 20;
fileFormatError = 0;
skippedFiles = 0;
global cancelBatch;
cancelBatch = 0;

% only lines within measureUnity+-faultLimit are considered OK
faultLimit = 5;

% mean hifi - mean multi-spot > abnormalLimit give a warning
abnormalLimit = 1;

% read unraster cutoff frequency (in percents) from GUI
cutoffRaster = str2double(get(handles.Filters_Unraster_edit,'String'));

% zone where the laid lines peak is to find
emboss2Offset = 4;  % with double emboss
emboss1Offset = 15; % with simple emboss

% in simple emboss there should be more than infra lines
simpleEmbossLineLimit = 5;

% calculates for 20 1/2 lines adding a half line
if get(handles.Scale_HalfLine_checkbox,'Value') == 1
    halfline = 0.5;
else
    halfline = 0;
end

% sets how many pixel represent a millimeter
if get(handles.Scale_contact_radiobutton,'Value') == 1
	% calculates from dpi the equivalent pixel number (1 inch = 25.4 mm)
	dpi = str2double(get(handles.Scale_dpi_edit,'String'));
	scale = 25.4/dpi;
else
    % gets scale from user input
	scale = get(handles.Scale_edit,'String');
	if findstr(scale,',') ~= []
        scale = strrep(scale,',','.');
	end
	scale = str2num(scale);
end

% gets spot dimension if centered trim
if get(handles.Filters_TrimOnOff_checkbox,'Value') == 1
    % get xy dimensions of image
    dy = size(get(findobj(gca,'Type','image'),'CData'),1);
    dx = size(get(findobj(gca,'Type','image'),'CData'),2);
    
    % get trimming values
    trimTop = str2num(get(handles.Filters_TrimTop_text,'String'));
    trimBottom = str2num(get(handles.Filters_TrimBottom_text,'String'));
    trimLeft = str2num(get(handles.Filters_TrimLeft_text,'String'));
    trimRight = str2num(get(handles.Filters_TrimRight_text,'String'));
    
    % spot dimensions
    trimRoiHeight = dy - trimTop - trimBottom;
    trimRoiWidth = dx - trimLeft - trimRight;
end

% seeks method
if get(handles.Method_HiFi_radiobutton,'Value') == 1
    methodInitial = 'hifi';
elseif get(handles.Method_MultiSpot_radiobutton,'Value') == 1
    if get(handles.Method_SpotHeight_checkbox,'Value') == 1
        methodInitial = 'auto multi-spot';
    else
        methodInitial = 'manual multi-spot';
    end
else
    methodInitial = 'global';
end

% display waitbar if batch on
figureHandlesIndex = 0;
if strcmp(imgNature, 'batch images') == 1 & ...
    get(handles.Varia_BatchDisplay_checkbox,'Value') == 0

    global waitbarHandle;
    waitbarHandle = waitbar(0,translate('Please wait...'),...
        'CreateCancelBtn','ad751(''Waitbar_pushbutton_Callback'')');
    set(findobj(waitbarHandle,'String','Cancel'),...
        'String',translate('Cancel'),...
        'Units','normalized',....
        'Position',[.6 .1 .3 .3]);
    set(waitbarHandle,'Name',['AD751: ',...
        translate('Analysing multiple images')]);
    pause(0)
end

% headers of data to be saved
resultsHeader = [...
       'AD751 - ',translate('counts parallel even spaced lines on a image'),...
       ' [ ',datestr(startTime,31),' ]',...
       '\n',translate('file'),...
       '\t',translate('method'),...
       '\t',translate('density [mm]'),...
       ' ',translate('lines'),...
       ];
resultsStats = [...
       resultsHeader,...
       '\t',translate('range'),...
       '\t',translate('standard deviation'),...
       '\t',translate('non-aberrant spots'),...
       '\t',translate('slant'),...
       ];
resultsSpots = [...
       resultsHeader,...
       ];
resultsLines = [...
       resultsHeader,' / ',translate('spot')];
resultsFault = [...
       resultsHeader,...
       ' ',translate('infered from spots with not between'),...
       ' [ ',num2str(measureUnity-faultLimit+1),...
       ' & ',num2str(measureUnity+faultLimit-1),...
       ' ] ',translate('lines'),...
       ];
resultsSettings = [...
       'AD751 - ',translate('counts parallel even spaced lines on a image'),...
       ' [ ',datestr(clock,31),' ]',...
       '\n',translate('File'),...
       '\t',translate('Method'),...
       '\t',translate('Height'),...
       '\t',translate('Trim top'),' [',translate('pixel'),']'...
       '\t',translate('Trim bottom'),...
       '\t',translate('Trim left'),...
       '\t',translate('Trim right'),...
       '\t',translate('Centered'),...
       '\t',translate('Axial orientation'),...
       '\t',translate('Double emboss'),...
       '\t',translate('Unraster'),...
       '\t',translate('Scale'),' [mm/pixel]',...
       '\t+ 1/2 ln',...
       '\t',translate('Images processed'),...
       '\t',translate('Total'),...
       '\t',translate('Remaining'),...
       '\t',translate('Start'),...
       '\t',translate('End'),...
       '\t',translate('Total'),...
       ];

% save results files
% ---
% statistics
resultsFile = translate('AD751 Results - Statistics.txt');
if exist([path,dirsep,resultsFile]) == 0
    resultsFile = fopen(resultsFile,'at');
    fprintf(resultsFile,resultsStats);
    fclose(resultsFile);
end

% spots
resultsFile = translate('AD751 Results - Spots.txt');
if exist([path,dirsep,resultsFile]) == 0
    resultsFile = fopen(resultsFile,'at');
    fprintf(resultsFile,resultsSpots);
    fclose(resultsFile);
end

% lines
resultsFile = translate('AD751 Results - Lines.txt');
if exist([path,dirsep,resultsFile]) == 0
    resultsFile = fopen(resultsFile,'at');
    fprintf(resultsFile,resultsLines);
    fclose(resultsFile);
end

% faulty spots
resultsFile = translate('AD751 Results - Faults.txt');
if exist([path,dirsep,resultsFile]) == 0
    resultsFile = fopen(resultsFile,'at');
    fprintf(resultsFile,resultsFault);
    fclose(resultsFile);
end

% settings
resultsFile = translate('AD751 Results - Settings.txt');
if exist([path,dirsep,resultsFile]) == 0
    resultsFile = fopen(resultsFile,'at');
    fprintf(resultsFile,resultsSettings);
    fclose(resultsFile);
end
% ---

% if batch, put time-stamp at beginings
if strcmp(imgNature, 'batch images') == 1
    timeStamp = ['\n\n[',translate('Start'),...
            ' ',translate('batch'),...
            ' ',num2str(datestr(startTime,31)),']'];
    
    % statistics
    resultsFile = fopen(translate('AD751 Results - Statistics.txt'),'at');
    fprintf(resultsFile,timeStamp);
    fclose(resultsFile);
    
    % spots
    resultsFile = fopen(translate('AD751 Results - Spots.txt'),'at');
    fprintf(resultsFile,timeStamp);
    fclose(resultsFile);
    
    % lines
    resultsFile = fopen(translate('AD751 Results - Lines.txt'),'at');
    fprintf(resultsFile,timeStamp);
    fclose(resultsFile);
    
    % faulty spots
    resultsFile = fopen(translate('AD751 Results - Faults.txt'),'at');
    fprintf(resultsFile,timeStamp);
    fclose(resultsFile);
end

% >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
% STARTING FILE NAME BATCHING

% get number of images to analyse
numberOfImages = size(InNameBatch,1);

% repeat analysis for all images
for imgNow = 1:numberOfImages

% remebers initail method seting 
% for not to change it in case of batch with method change
method = methodInitial;

% sets image name depending on number of images to analyse
if strcmp(imgNature, 'batch images') == 1
    if isempty(BatchList) == 1
        % get file names from directory
        InFileFullName = strcat(path,'\',char(InNameBatch(imgNow).name));
    else
        % get file names from list in a file
        InFileFullName = char(InNameBatch(imgNow));
    end
else
    InFileFullName = InNameBatch;
end

% extracts images name out of full path+file name
[InFilePath,InFileName,InFileExtension,InFileVersion] = fileparts(InFileFullName);

% makes a writing-to-file enabled variant (no escape characters)
InFileFullNameStr = strrep(InFileFullName,'\','/');

% FILTER IMAGE
% ---
% loads input image if any
if strcmp(imgNature, 'single image') == 1 | ...
        strcmp(imgNature, 'batch images') == 1
    try
        ImgIn = imread(InFileFullName);
    % error handling    
    catch
        fileFormatError = 1;
	end
end

if fileFormatError == 1;
    fileFormatError = 0;
    skippedFiles = skippedFiles + 1;
    continue
end

% convert image format to be able to do a fft on 1-layer Gray image
% & not 3-layer RGB image
if isgray(ImgIn) == 0
	if isrgb(ImgIn) == 1
        ImgIn = rgb2gray(ImgIn);
	else
        ImgIn = mat2gray(double(ImgIn));
	end
end
ImgProc = ImgIn;

% get xy dimensions of image
dx = size(ImgProc,2);
dy = size(ImgProc,1);

% trimming
if get(handles.Filters_TrimOnOff_checkbox,'Value') == 0;
    % dosen't trim image margins
    trimTop = 0;
    trimBottom = 0;
    trimLeft = 0;
    trimRight = 0;
	dyFiltered = dy;
	dxFiltered = dx;
else
    % get trimming values
    trimTop = str2num(get(handles.Filters_TrimTop_text,'String'));
    trimBottom = str2num(get(handles.Filters_TrimBottom_text,'String'));
    trimLeft = str2num(get(handles.Filters_TrimLeft_text,'String'));
    trimRight = str2num(get(handles.Filters_TrimRight_text,'String'));
    
    % reset if centered on
    if get(handles.Filters_TrimCentered_checkbox,'Value') == 1
        % calculate center coords
        dyHalf = floor(dy/2);
        dxHalf = floor(dx/2);
        
        % cutter values
        trimTop = dyHalf - floor(trimRoiHeight/2);
        trimBottom = dy - (dyHalf - floor(trimRoiHeight/2) + trimRoiHeight);
        trimLeft = dxHalf - floor(trimRoiWidth/2);
        trimRight = dx - (dxHalf - floor(trimRoiWidth/2) + trimRoiWidth);
    end
        
    % if the cutters touch or overlap then they are set to zero
    if dy - trimTop - trimBottom < 2 | ...
                trimTop < 0 | ...
                trimBottom < 0
        trimTop = 0;
        trimBottom = 0;
    end
    if dx - trimLeft - trimRight < 2 | ...
                trimLeft < 0 | ...
                trimRight < 0
        trimLeft = 0;
        trimRight = 0;
    end
        
    % trims image margins
    ImgProc = ImgProc(1+trimTop:dy-trimBottom,...
        1+trimLeft:dx-trimRight);
	dyFiltered = dy-trimTop-trimBottom;
	dxFiltered = dx-trimLeft-trimRight;
end

% set detrammage
unraster = 0;
if get(handles.Filters_Unraster_checkbox,'Value') == 1
    unraster = 1;
end

% ------------------------------------------------------------
% AXIAL ORIENTATION
% ------------------------------------------------------------

if get(handles.Filters_Orient_checkbox,'Value') == 1

    if get(handles.Filters_OrientShow_checkbox,'Value') == 1
		% display redress window
		colordef white;
        figure('Name',[InFileName,InFileExtension,': AD751 - ',...
            translate('Axial orientation')], ...
            'NumberTitle','off',...
            'Menubar','none',...
            'ButtonDownFcn','zoom on');
        
		subplot(221);
		currentObject = subimage(ImgProc);
		set(currentObject,'ButtonDownFcn','zoom on');
		axis on;
		set(gca,...
            'XTick',[],...
            'YTick',[]);
		ylabel([num2str(size(ImgProc,1)),' \times ',num2str(size(ImgProc,2)),...
                ' ',translate('pixel')]);
		title(translate('Input image'));
        drawnow;
    end

    % cuts the image square to not distort the rotation angles
    xImgRedres = size(ImgProc,2);
    yImgRedres = size(ImgProc,1);
    nSquareFft = min([yImgRedres, xImgRedres]);
    % compensate for even dimension
    % (work on on odd dimension images to avoid max frq traps)
    if rem(nSquareFft,2) == 0
        nSquareFft = nSquareFft-1;
    end
    % show square
	xRedres = floor(xImgRedres/2 - nSquareFft/2);
	yRedres = floor(yImgRedres/2 - nSquareFft/2);
    if get(handles.Filters_OrientShow_checkbox,'Value') == 1
    	rectangle('Position',[xRedres+1 yRedres+1 nSquareFft-1 nSquareFft-1],...
            'EdgeColor','green');
    end

    % Getting noise from emboss
    % ---
    % calculate 2D Fast Fourier transform from emboss
    ImgRedres = emboss(ImgProc);
    if get(handles.Filters_Emboss_checkbox,'Value') == 1
	    ImgRedres = emboss(ImgRedres);
    end
	ImgRedres = abs(fft2(ImgRedres,nSquareFft,nSquareFft));
    
    % zeros the constant component
    ImgRedres(1,1) = 0;
    % cuts 1/2 of the symetric matrix
    ImgRedres = ImgRedres(1:ceil(size(ImgRedres,1)/2),:);
    % memorize data
    ImgRedresEmboss = ImgRedres;
    % unraster
    if unraster == 1
        ImgRedres = maskFft(ImgRedres,cutoffRaster);
    end
    % get number of lines anywhere it is on the image
    % --- BUG? --------------------------------------
    % matrix row entry #1 corresponds to frequency 0,
    % so one has to subtract 1 to get the right number of frequencies,
    % but AD751 gives optimal results only if 1 is not subtracted
    % but added (see line #919)!
    % -----------------------------------------------
    linesNow = max2(ImgRedres,1)-1;
    linesNowPower = max2(ImgRedres,3);
    % set noise
    if get(handles.Filters_Emboss_checkbox,'Value') == 1
        noise = linesNow - emboss2Offset;
    else
        noise = linesNow - emboss1Offset;
    end
    % noise error trapping
    if noise < 0
        noise = 1;
    end
    % ---
    
    % 2D Fast Fourier transform of initial image
    ImgRedresAxis = abs(fftshift(fft2(ImgProc,nSquareFft,nSquareFft)));
    ImgRedres = log(ImgRedresAxis);
    
    % 2D top-view
    % ---
    % put coordinate origin in center of image
    fftHalf = floor(nSquareFft/2);
    fftCoord = [-fftHalf,fftHalf];
    
    if get(handles.Filters_OrientShow_checkbox,'Value') == 1
        % plots
        subplot(222);
        currentObject = imshow(fftCoord,fftCoord,...
            ImgRedres,[],'notruesize');
        if unraster == 1
            % show unraster area
            cutoffPixels = fftHalf-floor(fftHalf*cutoffRaster/100);
            rectangle('Position',...
                [-cutoffPixels,-cutoffPixels...
                    2*cutoffPixels+1,2*cutoffPixels+1],...
                'EdgeColor','red');
            text(-cutoffPixels,...
                -cutoffPixels,...
                [translate('unraster cutoff'),' ',num2str(cutoffRaster),'%'],...
                'HorizontalAlignment','left',...
                'VerticalAlignment','bottom',...
                'Color','black');
        end
		set(currentObject,'ButtonDownFcn','zoom on');
		axis on;
		colormap(jet);
		title(translate('Fourier transform'));
        drawnow;
        % ---
    
        % side-views
    	subplot(223);
        % ---
		% cuts 1/2 of the symetric matrix for vizualization
        FftHalfRows = floor(size(ImgRedresAxis,1)/2);
        ImgRedresAxis = ImgRedresAxis(FftHalfRows+2:size(ImgRedresAxis,1),:);
	
        % 2D y-axis side-view on not filtered image's fft
        currentObject = plot(ImgRedresAxis);
		set(currentObject,'ButtonDownFcn','zoom on');
		set(gca,'TickDir','out');
		axis on;
        axis tight;
        axis square;
		title(translate('Lower y-axis'));
		xlabel([translate('periods / image (noise: '),num2str(noise-1),')']);
		ylabel(translate('power'));
        if unraster == 1
            axisLim = axis;
            % show unraster cuttoff frequency
            line([cutoffPixels,cutoffPixels],...
                [0,axisLim(4)],...
                'Color','red');
        end
        drawnow;
        
        % y-axis side-view on filtered image's fft
        subplot(224);
        currentObject = plot(ImgRedresEmboss(2:end,:));
        set(currentObject,'ButtonDownFcn','zoom on');
        set(gca,'TickDir','out');
        axis on;
        axis tight;
        axis square;
        xlabel(['...',translate('after'),' ',...
                num2str(get(handles.Filters_Emboss_checkbox,'Value')+1),...
                ' \times ',translate('image emboss')]);
        ylabel(translate('power'));
        if unraster == 1
            axisLim = axis;
            % show unraster cuttoff frequency
            line([cutoffPixels,cutoffPixels],...
                [0,axisLim(4)],...
                'Color','red');
        end
        drawnow;        
    end

    % filtering noise
    % ---
    ImgRedresSide = size(ImgRedres,1);
    
    % Set noise area to zero
    ImgRedres((fftHalf+1-noise):(fftHalf+1+noise), 1:ImgRedresSide) = ...
        zeros((noise*2+1),ImgRedresSide);

    if unraster == 1
        % unraster
        cutoffPixels = floor(ImgRedresSide*cutoffRaster/200);
        mask = zeros(ImgRedresSide);
        mask(cutoffPixels:ImgRedresSide-cutoffPixels, ...
            cutoffPixels:ImgRedresSide-cutoffPixels) = ...
            ImgRedres(cutoffPixels:ImgRedresSide-cutoffPixels, ...
            cutoffPixels:ImgRedresSide-cutoffPixels);
        ImgRedres = mask;
    end
    % ---

    % Gets the maximas
    % ---
    % first part
 	maxFft1 = max2(ImgRedres);
 	ImgRedres(maxFft1(1),maxFft1(2)) = 0;
    % symetrical part
 	maxFft2 = max2(ImgRedres);

    if get(handles.Filters_OrientShow_checkbox,'Value') == 1
        % points out the maximas
		subplot(222);
        hold on;
        text(maxFft1(2)-fftHalf-1,...
            maxFft1(1)-fftHalf-1,...
            'max \rightarrow',...
            'HorizontalAlignment','right',...
            'Color','black');
        text(maxFft2(2)-fftHalf-1,...
            maxFft2(1)-fftHalf-1,...
            '\leftarrow max',...
           'HorizontalAlignment','left',...
            'Color','black');
        xlabel(['max: ',num2str(maxFft1(2)-fftHalf-1),...
                ' & ',num2str(maxFft2(2)-fftHalf-1),' ',translate('pixel')]);
        ylabel(['max: ',num2str(fftHalf-maxFft1(1)+1),...
                ' & ',num2str(fftHalf-maxFft2(1)+1),' ',translate('pixel')]);
		subplot(223);
        hold on;
        text(abs(maxFft2(1)-fftHalf)+1,...
            exp(maxFft2(3)),...
            '\leftarrow max',...
            'HorizontalAlignment','left',...
            'Color','black');
		subplot(224);
        hold on;
        text(linesNow,...
            linesNowPower,...
            '\leftarrow max',...
            'HorizontalAlignment','left',...
            'Color','black');
        drawnow;
    end
    % ---   
    
    % gets slant
    %
    % if img upright prevent divide by zero in tan
    if maxFft2(2)-maxFft1(2) == 0
        slant = 0;
    else
        slant = 90+rad2deg(...
            atan((maxFft2(1)-maxFft1(1))/...
                 (maxFft2(2)-maxFft1(2))));
    end
    if slant > 90
        slant = slant - 180;
    end
	
    if get(handles.Filters_OrientShow_checkbox,'Value') == 1
		% writes & draws the slant
		subplot(221);
		hold on;
        ImgProcX = size(ImgProc,2);
        ImgProcY = size(ImgProc,1);
		line([1,ImgProcX],...
            [ImgProcY/2 - (ImgProcX/2)*tan(deg2rad(slant)),...
            ImgProcY/2 + (ImgProcX/2)*tan(deg2rad(slant))],...
            'Color','red');
		xlabel(['\bf',num2str(slant,'%1.1f'),' ',translate('slant')],...
            'Color','red');
        drawnow;
    end

    if slant ~= 0
        % redress trimmed image
        ImgProc = roirotate(ImgIn,...
            [trimLeft+1,trimTop+1,...
                dx-trimRight-trimLeft-1,dy-trimBottom-trimTop-1],...
            slant,'bicubic');
    end
    % sets slant
    slant = num2str(slant,'%1.1f');
else
    slant = '-';
end

% continue
% return

% ------------------------------------------------------------
% ANALYSIS
% ------------------------------------------------------------

% Initialisation
dyFiltered = size(ImgProc,1);
dxFiltered = size(ImgProc,2);
ImgProcEmboss = emboss(ImgProc);
if get(handles.Filters_Emboss_checkbox,'Value') == 1
    ImgProcEmboss = emboss(ImgProcEmboss);
end
lineDensityMax = realmax;
multispotDensities = [];
allLines = 0;
errorSpotNbr = 0;

% Displays analysis figure
% only if not batch or batch and set to 'display on'
if strcmp(imgNature, 'batch images') ~= 1 | ...
        (strcmp(imgNature, 'batch images') == 1 & ...
        get(handles.Varia_BatchDisplay_checkbox,'Value') == 1)
    
    % creates analysis figure
	colordef white;
	analysisFigureHandle = figure('Name',[InFileName,InFileExtension,...
        ': AD751 - ',translate('Analysis'),': ',translate(method)],...
        'NumberTitle','off',...
        'Menubar','none',...
        'ButtonDownFcn','zoom on');
	
	% display Input image
	currentObject = subimage(ImgProc);
    set(currentObject,'ButtonDownFcn','zoom on');
    set(gca,'TickDir','out');
    axis on;
	xlabel([num2str(dxFiltered),' ',translate('pixel')]);
	ylabel([num2str(dyFiltered),' ',translate('pixel')]);
    resultsText = {translate('Drink coffee - the machine is working...')};
    title(resultsText,'Color','red','FontWeight','bold');
    drawnow;
end

% Three method count: global, multi-spot & HiFi
% ------------------------------------------------------------
% 1. HIFI METHOD
% ------------------------------------------------------------
if strcmp(method, 'hifi') == 1
    % Initialisation
	spotX1 = 1;
	spotX2 = dxFiltered;
	spotY1 = 1;
	spotHeight = 128;
	loopCount = 0;
    hifiDensities = [];
    spotAllRectanglesHandles = [];
    spotAllTextHandles = [];
    
	% only if not batch or batch and set to 'display on'
	if strcmp(imgNature, 'batch images') ~= 1 | ...
            (strcmp(imgNature, 'batch images') == 1 & ...
            get(handles.Varia_BatchDisplay_checkbox,'Value') == 1)
	
		% points to actual position
		positionMarker = text(...
            (spotX2-spotX1)/10,spotY1,...
            '\rightarrow ',...
            'HorizontalAlignment','right',...
            'FontSize',24,...
            'FontWeight','bold',...
            'Color','yellow');
	end
	
    % Moves a spot across the image &
	% resizes it until it reaches 20 lines
	%
	% while encore place to put a spot on the image
	while spotY1 + spotHeight - 1 <= dyFiltered
        
		% only if not batch or batch and set to 'display on'
		if strcmp(imgNature, 'batch images') ~= 1 | ...
                (strcmp(imgNature, 'batch images') == 1 & ...
                get(handles.Varia_BatchDisplay_checkbox,'Value') == 1)
	
            % change position marker
            set(positionMarker,'Position',[(spotX2-spotX1)/10,spotY1]);
            drawnow;
        end
        
        % cut a spot de spotHeight at spotStart
        % (1=2-1 where 2 is a saftey valve for equalising emboss with no emboss fft)
        SpotImg = ImgProcEmboss(spotY1:spotY1+spotHeight-1,spotX1:spotX2);
        
        % trap black spots (images with one grey value blocks AD751)
        if sum(sum(ImgProc(spotY1:spotY1+spotHeight-1,spotX1:spotX2))) == 0
            spotY1 = spotY1 + floor(spotHeight/2);
            continue
        end
        
        % Get noise from emboss spot
        %
        % calculate 2D Fast Fourier transform from emboss
		SpotFft = abs(fft2(SpotImg));
        % zeros the constant component
        SpotFft(1,1) = 0;
        % cuts 1/2 of the symetric matrix
        SpotFft = SpotFft(1:ceil(size(SpotFft,1)/2),:);
        % unraster
        if unraster == 1
            SpotFft = maskFft(SpotFft,cutoffRaster);
        end
        % get number of lines on y-axis only (0 slant)
        linesNow = max2(SpotFft,1);
        % enlarge spots with low line density
        if linesNow < measureUnity + 1
            spotHeight = spotHeight + 15;
            continue
        end
        % set noise
        if unraster == 0
            noise = linesNow - emboss2Offset;
        else
            noise = linesNow - emboss1Offset;
        end
        % noise error trapping
        if noise < 0
            noise = 1;
        end

        % Rescaling spot height to 20 lines
        %
        % bottom: cut or add on not-emboss until lines number = 20
        spotCut = 0;
        loopCount = 0;
	
        while linesNow ~= measureUnity
            % cut spot from image
            SpotImg = ImgProc(spotY1:spotY1+spotHeight-1-spotCut,...
                spotX1:spotX2);
            % calculate 2D Fast Fourier transform
            SpotFft = abs(fft2(SpotImg));
            % cuts 1/2 of the symetric matrix
            SpotFft = SpotFft(1:ceil(size(SpotFft,1)/2),:);
     		% cuts out noise signal
			SpotFft(1:noise,:) = zeros(noise,size(SpotFft,2));
            % unraster
            if unraster == 1
                SpotFft = maskFft(SpotFft,cutoffRaster);
            end
            % gets lines maximum on y-axis only (0 slant)
            linesNow = max2(SpotFft,1);
            % increment cutted row
            spotCut = spotCut + 1;
            
            % error trapping in case 20 lines not found
            loopCount = loopCount + 1;
            if loopCount == 50
                break
            end
        end
	
        % top: cut or add on not-emboss until lines number = 19
        if loopCount ~= 50
            spotHeight = size(SpotImg,1);
            spotCut = 1;
            loopCount = 0;
	
            while linesNow ~= measureUnity - 1
                % cut spot from image
                SpotImg = ImgProc(spotY1+spotCut:spotY1+spotHeight-1,...
                    spotX1:spotX2);
                % calculate 2D Fast Fourier transform
				SpotFft = abs(fft2(SpotImg));
                % cuts 1/2 of the symetric matrix
                SpotFft = SpotFft(1:ceil(size(SpotFft,1)/2),:);
         		% cuts out noise signal
				SpotFft(1:linesNow-2,:) = zeros(linesNow-2,size(SpotFft,2));
                % unraster
                if unraster == 1
                    SpotFft = maskFft(SpotFft,cutoffRaster);
                end
                % gets lines maximum
                linesNow = max2(SpotFft,1);
                % increment cutted row
                spotCut = spotCut + 1;
            
                % error trapping in case 20 lines not found
                loopCount = loopCount + 1;
                if loopCount == 50
                    break
                end
            end

            % Get density
            if loopCount ~= 50
	
                % restore one pixel row on top
                spotY1 = spotY1;    % <--- SOMETHING MISSING? ---
                spotHeight = size(SpotImg,1) + 1;
                spotCut = spotCut - 2;
                linesNow = linesNow + 1;
	
                % calculate over how many mm span 20 or 20 1/2 lines
				lineDensity = (measureUnity+halfline)*scale*...
                    (spotHeight/linesNow);
                
                % only if not batch or batch and set to 'display on'
				if strcmp(imgNature, 'batch images') ~= 1 | ...
                        (strcmp(imgNature, 'batch images') == 1 & ...
                        get(handles.Varia_BatchDisplay_checkbox,'Value') == 1)
	
                    % write density and rectangle
                    spotRectangleHandle = rectangle('Position',[...
                        spotX1,...
                        spotY1 + spotCut,...
                        spotX2 - 1,...
                        spotHeight - 1],...
                        'Curvature',[.1],...
                        'EdgeColor','green');
                    spotTextHandle = text(...
                        (spotX2 - spotX1)/2,...
                        spotY1 + spotCut + floor(spotHeight/4),...
                        [num2str(lineDensity,'%11.1f'),' mm'],...
                        'FontWeight','bold',...
                        'HorizontalAlignment','center',...
                        'Color','green');
                    drawnow;

                    % memorize handles
                    spotAllRectanglesHandles = ...
                        [spotAllRectanglesHandles, spotRectangleHandle];
                    spotAllTextHandles = ...
                        [spotAllTextHandles, spotTextHandle];
                end
			
                % memorize densities
                hifiDensities = [hifiDensities, lineDensity];
                
                % increment spot start
                spotY1 = spotY1 + floor(spotHeight/2);
            end
        end
        
        % increment spot start in case of failure to find exact number of lines
        if loopCount == 50
            spotY1 = spotY1 + 5;
        end
	end
	% only if not batch or batch and set to 'display on'
	if strcmp(imgNature, 'batch images') ~= 1 | ...
            (strcmp(imgNature, 'batch images') == 1 & ...
            get(handles.Varia_BatchDisplay_checkbox,'Value') == 1)

        delete(positionMarker);
    end
    
    % make a multi-spot check of hifi results validity
    method = 'hifi check';
    
	% if hifi count failed
	if sum(hifiDensities) == 0
        % Changes figure name
        method = 'auto multi-spot';
        
		% only if not batch or batch and set to 'display on' do write
		if strcmp(imgNature, 'batch images') ~= 1 | ...
                (strcmp(imgNature, 'batch images') == 1 & ...
                get(handles.Varia_BatchDisplay_checkbox,'Value') == 1)

            set(analysisFigureHandle,'Name',[InFileName,InFileExtension,...
                ': AD751 - ',translate('Analysis'),': ',translate(method)]);
            textHandle = text(...
                (spotX2 - spotX1)/2,...
                dyFiltered - 25,...
                [translate('No'),' ',num2str(measureUnity),...
                 ' ',translate('even spaced lines found with hifi method.')],...
                'FontWeight','bold',...
                'HorizontalAlignment','center',...
                'Color','red');
        end
	end
    
    % if hifi gave aberrant results
    % aberrant = lower than 13 mm
end

% ------------------------------------------------------------
% 2. MULTI-SPOT & GLOBAL MEASURE
% ------------------------------------------------------------
% sets spot dimensions
spotWidth = dxFiltered;
if strcmp(method, 'global') == 1
	spotHeight = dyFiltered;
	% reduce spot to image dimension if bigger
	if spotHeight > dyFiltered
        spotHeight = dyFiltered;
	end
else
    if strcmp(method, 'manual multi-spot') == 1
        % USER SET HEIGHT
        spotHeight = round(str2num(get(handles.Method_SpotHeight_edit,'String')));
    else
        % AUTO HEIGHT
        % inferes the probable height from a global measure
        spotHeight = dyFiltered;

        % global count
        % ---
        % calculates the spots coordinates
        ImgSpot = ImgProc;
        ImgSpotEmboss = ImgProcEmboss;
        
        % Getting noise from emboss
        %
        for temp = 1:2
            % calculate 2D Fast Fourier transform from emboss
            ImgFft = abs(fft2(ImgSpotEmboss));
            % zeros the constant component
            ImgFft(1,1) = 0;
            % cuts 1/2 of the symetric matrix
            ImgFft = ImgFft(1:ceil(size(ImgFft,1)/2),:);
            % unraster
            if unraster == 1
                ImgFft = maskFft(ImgFft,cutoffRaster);
            end
            % get number of lines anywhere it is on the image
            linesNow = max2(ImgFft,1);
            % set noise
            if unraster == 0
                noise = linesNow - emboss2Offset;
            else
                noise = linesNow - emboss1Offset;
            end
            % if double emboss off & too few lines it's a fault 
            % & 2emboss should be on
            if (get(handles.Filters_Emboss_checkbox,'Value') == 0 & ...
                    noise > simpleEmbossLineLimit) | ...
                    temp == 2
                break
            end
            ImgSpotEmboss = emboss(ImgSpotEmboss);
        end
        
        % Getting line qnty from normal image
        %
        % calculate 2D Fast Fourier transform
		ImgFft = abs(fft2(ImgSpot));
		% zeros the constant component
        ImgFft(1,1) = 0;
		% cuts 1/2 of the symetric matrix
        ImgFft = ImgFft(1:ceil(size(ImgFft,1)/2),:);
        % unraster
        if unraster == 1
            ImgFft = maskFft(ImgFft,cutoffRaster);
        end
		% cuts out noise signal
		ImgFft(1:noise,:) = zeros(noise,size(ImgFft,2));
		% Memorise maximum Fft point
        % get number of lines
        linesMax = max2(ImgFft,1);
        % ---
		
		% Cuts the image to exact peak-to-peak distance
        % ---
		% gets line density of maximum spot
		ImgTemp = ImgSpot;
		linesNow = linesMax;
		cutPixelTop = 0;
		cutPixelBottom = 0;
		
		% trims top & bottom of images until it reaches an exact
		% multiple of the periods (cuts at the peak of the first
		% & last period)
		%
		% top trim
		while linesNow == linesMax
            ImgTemp = imcrop(ImgTemp,[1,2,spotWidth-1,size(ImgTemp,1)-2]);
            
            % calculate 2D Fast Fourier transform
			ImgFft = abs(fft2(ImgTemp));
            % zeros the constant component
            ImgFft(1,1) = 0;
            % cuts 1/2 of the symetric matrix
            ImgFft = ImgFft(1:ceil(size(ImgFft,1)/2),:);
            % unraster
            if unraster == 1
                ImgFft = maskFft(ImgFft,cutoffRaster);
            end
			% cuts out noise signal
			ImgFft(1:noise,:) = zeros(noise,size(ImgFft,2));
            % gets lines maximum
            linesNow = max2(ImgFft,1);
            
            % increment counter of how many pixels where cut
            cutPixelTop = cutPixelTop + 1;
		end
		
		% bottom trim
		ImgSpot = imcrop(ImgSpot,[1,cutPixelTop,...
                spotWidth,size(ImgSpot,1) - cutPixelTop]);
		ImgTemp = ImgSpot;
		linesNow = linesMax;
		while linesNow == linesMax
            ImgTemp = imcrop(ImgTemp,[1,1,spotWidth-1,size(ImgTemp,1)-2]);
            
            % calculate 2D Fast Fourier transform
			ImgFft = abs(fft2(ImgTemp));
            % zeros the constant component
            ImgFft(1,1) = 0;
            % cuts 1/2 of the symetric matrix
            ImgFft = ImgFft(1:ceil(size(ImgFft,1)/2),:);
            % unraster
            if unraster == 1
                ImgFft = maskFft(ImgFft,cutoffRaster);
            end
     		% cuts out noise signal
			ImgFft(1:noise,:) = zeros(noise,size(ImgFft,2));
            % gets lines maximum
            linesNow = max2(ImgFft,1);
            
            % increment counter of how many pixels where cut
            cutPixelBottom = cutPixelBottom + 1;
		end
		
        % compensation to make the period run from the first amplitude
        % to just before the next & not the next included
        cutPixelBottom = cutPixelBottom - 2;
        linesNow = linesNow + 1;
        
		% period exact spot image
		ImgSpot = imcrop(ImgSpot,[1,1,...
                spotWidth-1,size(ImgSpot,1) - cutPixelBottom]);
		spotHeight = size(ImgSpot,1);
        % ---
        
        % inferes spot height
        spotHeight = floor(measureUnity*spotHeight/linesNow);
        if spotHeight > dyFiltered
            spotHeight = dyFiltered;
        end
    end
end

% Fourier transform preparations
linesMax = 0;

if strcmp(method, 'hifi check') ~= 1
    % prepare results for output in file
	resultsSpots = [...
           '\n',InFileFullNameStr,...
           '\t',translate(method)];
   
	resultsFault = [...
           '\n',InFileFullNameStr,...
           '\t',translate(method)];
    
	resultsLines = [...
           '\n',InFileFullNameStr,...
           '\t',translate(method)];
end

% sets number of spots
spotRowTotal = floor(dyFiltered/spotHeight);
% sets pading (pixels left over if spot would be moved with a step equal to itself)
spotPadY = floor(dyFiltered/spotRowTotal - spotHeight);
% doubles the number of spots - one each half spot-height
spotRowTotal = spotRowTotal*2 - 1;
spotY2 = (spotHeight+spotPadY) - floor((spotHeight+spotPadY)/2);

% moves a spot across the image
for spotRow = 1:spotRowTotal
    % initialise
    faultySpot = 0;
    
	% only if not batch or batch and set to 'display on'
	if strcmp(method, 'hifi check') ~= 1 &...
        (strcmp(imgNature, 'batch images') ~= 1 | ...
        (strcmp(imgNature, 'batch images') == 1 & ...
        get(handles.Varia_BatchDisplay_checkbox,'Value') == 1))
    
        % initialise
        drawnow;
    end
    
    % calculates the spots coordinates
    spotY2 = spotY2 + floor((spotHeight+spotPadY)/2);
    spotY1 = spotY2 - spotHeight + 1;
    spotCoord = [1 dxFiltered; spotY1 spotY2];
    ImgSpot = ImgProc(spotY1:spotY2,1:dxFiltered);
    ImgSpotEmboss = ImgProcEmboss(spotY1:spotY2,1:dxFiltered);

    % trap black spots (images with one grey value blocks AD751)
    if sum(sum(ImgSpot)) == 0
        continue
    end

    % Getting noise from emboss
    %
    % calculate 2D Fast Fourier transform from emboss
    for temp = 1:2
        ImgFft = abs(fft2(ImgSpotEmboss));
        % zeros the constant component
        ImgFft(1,1) = 0;
        % cuts 1/2 of the symetric matrix
        ImgFft = ImgFft(1:ceil(size(ImgFft,1)/2),:);
        % unraster
        if unraster == 1
            ImgFft = maskFft(ImgFft,cutoffRaster);
        end
        % get number of lines anywhere it is on the image
        linesNow = max2(ImgFft,1);
        % trap faulty images or tamis
        if (strcmp(method, 'global') ~= 1) & ...
                (linesNow - 1 <= measureUnity-faultLimit | ...
                linesNow - 1 >= measureUnity+faultLimit)
            faultySpot = 1;
        end
        % set noise
        if unraster == 0
            noise = linesNow - emboss2Offset;
        else
            noise = linesNow - emboss1Offset;
        end
        % if double emboss off & too few lines it's a fault 
        % & 2emboss should be on
        if (get(handles.Filters_Emboss_checkbox,'Value') == 0 & ...
                noise > simpleEmbossLineLimit) | ...
                temp == 2
            break
        end
        ImgSpotEmboss = emboss(ImgSpotEmboss);
        faultySpot = 0;
    end

    % Getting line qnty from normal image
    %
    % calculate 2D Fast Fourier transform
	ImgFft = abs(fft2(ImgSpot));
	% zeros the constant component
    ImgFft(1,1) = 0;
	% cuts 1/2 of the symetric matrix
    ImgFft = ImgFft(1:ceil(size(ImgFft,1)/2),:);
    % unraster
    if unraster == 1
        ImgFft = maskFft(ImgFft,cutoffRaster);
    end
	% cuts out noise signal
	ImgFft(1:noise,:) = zeros(noise,size(ImgFft,2));
    % get number of lines
    linesNow = max2(ImgFft,1);

	% Cuts the image to exact peak-to-peak distance
    % ---
	% gets line density of maximum spot
	ImgTemp = ImgSpot;
	linesTemp = linesNow;
	cutPixelTop = 0;
	cutPixelBottom = 0;
	
	% trims top & bottom of images until it reaches an exact
	% multiple of the periods (cuts at the peak of the first
	% & last period)
	%
	% top trim
	while linesTemp == linesNow
        ImgTemp = imcrop(ImgTemp,[1,2,spotWidth-1,size(ImgTemp,1)-2]);
        
        % calculate 2D Fast Fourier transform
		ImgFft = abs(fft2(ImgTemp));
        % zeros the constant component
        ImgFft(1,1) = 0;
        % cuts 1/2 of the symetric matrix
        ImgFft = ImgFft(1:ceil(size(ImgFft,1)/2),:);
		% cuts out noise signal
		ImgFft(1:noise,:) = zeros(noise,size(ImgFft,2));
        % unraster
        if unraster == 1
            ImgFft = maskFft(ImgFft,cutoffRaster);
        end
        % gets lines maximum
        linesTemp = max2(ImgFft,1);
        
        % increment counter of how many pixels where cut
        cutPixelTop = cutPixelTop + 1;
	end
	
	% bottom trim
	ImgSpot = imcrop(ImgSpot,[1,cutPixelTop,...
            spotWidth,size(ImgSpot,1) - cutPixelTop]);
	ImgTemp = ImgSpot;
	linesTemp = linesNow;
	while linesTemp == linesNow
        ImgTemp = imcrop(ImgTemp,[1,1,spotWidth-1,size(ImgTemp,1)-2]);
        
        % calculate 2D Fast Fourier transform
		ImgFft = abs(fft2(ImgTemp));
        % zeros the constant component
        ImgFft(1,1) = 0;
        % cuts 1/2 of the symetric matrix
        ImgFft = ImgFft(1:ceil(size(ImgFft,1)/2),:);
 		% cuts out noise signal
		ImgFft(1:noise,:) = zeros(noise,size(ImgFft,2));
        % unraster
        if unraster == 1
            ImgFft = maskFft(ImgFft,cutoffRaster);
        end
        % gets lines maximum
        linesTemp = max2(ImgFft,1);
        
        % increment counter of how many pixels where cut
        cutPixelBottom = cutPixelBottom + 1;
	end
	
    % compensation to make the period run from the first amplitude
    % to just before the next & not the next included
    cutPixelBottom = cutPixelBottom - 2;
    linesNow = linesTemp + 1;
    
	% period exact spot image
	ImgSpot = imcrop(ImgSpot,[1,1,...
            spotWidth-1,size(ImgSpot,1) - cutPixelBottom]);
	spotHeightNow = size(ImgSpot,1);
    % ---
    
    % calculate over how many mm span 20 or 20 1/2 lines
	lineDensity = (measureUnity+halfline)*scale*...
        (spotHeightNow/linesNow);

    if strcmp(method, 'hifi check') == 0
        if faultySpot == 0
            % prepare results for output in file
			resultsSpots = [resultsSpots,...
                   '\t',num2str(lineDensity,'%1.1f')];
			resultsFault = [resultsFault,...
                   '\t-'];
        
            % memorize densities
            multispotDensities = [multispotDensities, lineDensity];                
        else
            % faulty spots memorised for file
			resultsSpots = [resultsSpots,...
                   '\t-'];
			resultsFault = [resultsFault,...
                   '\t',num2str(lineDensity,'%1.1f')];
        end
		resultsLines = [resultsLines,...
               '\t',num2str(linesNow)];
       
        % displays spots if any
		% only if not batch or batch and set to 'display on'
		if strcmp(imgNature, 'batch images') ~= 1 | ...
            (strcmp(imgNature, 'batch images') == 1 & ...
            get(handles.Varia_BatchDisplay_checkbox,'Value') == 1)
        
            spotRectangleHandle = rectangle('Position',[...
                spotCoord(1,1),...
                spotCoord(2,1),...
                spotWidth-1,...
                spotHeightNow-1],...
                'Curvature',[.1],...
                'EdgeColor','green');
            spotTextHandle = text(spotCoord(1,1) + spotWidth/2,...
                spotCoord(2,1) + spotHeightNow/4,...
                [num2str(lineDensity,'%11.1f'),' mm \rm[',num2str(linesNow),' ln]'],...
                'FontWeight','bold',...
                'HorizontalAlignment','center',...
                'Color','green');
            
            % faulty spots in yellow
            if faultySpot == 0
                % memorize highest density spot
                if lineDensity < lineDensityMax
                    lineDensityMax = lineDensity;
                    spotRectangleMaxHandle = spotRectangleHandle;
                    spotTextMaxHandle = spotTextHandle;
                end
            else
                set(spotRectangleHandle,'EdgeColor','yellow'); 
                set(spotTextHandle,'Color','yellow'); 
            end
        end
    else
        if faultySpot == 0
            % memorize spot densities & lines
            multispotDensities = [multispotDensities, lineDensity];
        end
    end
    
    % gets number of non-aberrant spots
    nbrOfNormalSpots = size(multispotDensities,2);
    
end % SpotRows;

% ------------------------------------------------------------
% SAVE RESULTS
% ------------------------------------------------------------

% detect abnormal hifi values
if strcmp(method, 'hifi check') == 1
    % restore
    method = 'hifi';
    linesNow = measureUnity;

    % prepare results for output in file
	resultsCommon = [...
           '\n',InFileFullNameStr,...
           '\t',translate(method),...
           ]; 
	resultsSpots = [resultsCommon]; 
	resultsFault = [resultsCommon]; 
	resultsLines = [resultsCommon]; 

    % calculate mean density in multi-spot mode
    meanDensity = mean(hifiDensities);
    if sum(multispotDensities) ~= 0
        meanMultispotDensity = mean(multispotDensities);
    else
        meanMultispotDensity = meanDensity;
    end

    % compute normal values
	if (abs(meanDensity - meanMultispotDensity) < abnormalLimit)
        % gets number of non-aberrant spots
        nbrOfNormalSpots = size(hifiDensities,2);
        
        % finds position of maximum density spot
        [i,maxSpotNbr] = min(hifiDensities);

        % recomputes statistics
        meanDensity = mean(hifiDensities);
        rangeSpots = range(hifiDensities);
        standardDevSpots = std(hifiDensities);
            
        % prepare results for output in file
        tempSpots = [];
        tempFault = [];
        tempLines = [];
        for i = 1:size(hifiDensities,2)
            tempSpots = [tempSpots,...
                    '\t',num2str(hifiDensities(1,i),'%1.1f')];
            tempFault = [tempFault,...
                    '\t-'];
            tempLines = [tempLines,...
                    '\t20'];
        end
		resultsSpots = [resultsSpots,tempSpots]; 
		resultsFault = [resultsFault,tempFault]; 
		resultsLines = [resultsLines,tempLines]; 

    else % compute abnormal values
        
        % gets number of non-aberrant spots
        nbrOfNormalSpots = size(hifiDensities,2)-1;
        
        % removes the abnormal density depending on number of found spots
        if size(hifiDensities,2) == 1
            % recomputes statistics
            meanDensity = '-';
            rangeSpots = '-';
            standardDevSpots = '-';
            
            % memorize number of faulty spots
            errorSpotNbr = 1;
            
            % establish matrix index of maximum density
            maxSpotNbr = 1;

            % move abnormal spot data
            tempSpots = ['\t-'];
            tempFault = ['\t',num2str(hifiDensities,'%1.1f')];
            tempLines = ['\t20'];
                
        elseif size(hifiDensities,2) == 2
            % find farthes spot away from multi-spot mean
            [abnormalDensity,errorSpotNbr] = ...
                max([abs(hifiDensities(1,1)-meanMultispotDensity),...
                abs(hifiDensities(1,2)-meanMultispotDensity)]);
            abnormalDensity = hifiDensities(1,errorSpotNbr);
            % removes it
            hifiDensities = hifiDensities(1,abs(errorSpotNbr-2)+1);
            
            % recomputes statistics
            meanDensity = mean(hifiDensities);
            rangeSpots = range(hifiDensities);
            standardDevSpots = std(hifiDensities);
            
            % establish matrix index of maximum density
            maxSpotNbr = abs(errorSpotNbr-2)+1;
            
           % move abnormal spot data
            if errorSpotNbr == 1
                tempSpots = ['\t-\t',...
                        num2str(hifiDensities,'%1.1f')];
                tempFault = ['\t',num2str(abnormalDensity,'%1.1f'),...
                        '\t-'];
            else
                tempSpots = ['\t',num2str(hifiDensities,'%1.1f'),...
                        '\t-'];
                tempFault = ['\t-\t',...
                        num2str(abnormalDensity,'%1.1f')];
            end
            tempLines = '\t20\t20';
            
        else
            % computes skew to know where the abnormality is
            if sign(skewness(hifiDensities,0)) > 0;
                % locates the maximum density
                [abnormalDensity,errorSpotNbr] = max(hifiDensities);
            else
                % locates the minimum density
                [abnormalDensity,errorSpotNbr] = min(hifiDensities);
            end
            
            % removes the abnormal density
            if errorSpotNbr+1 > size(hifiDensities,2)
                errorSpotNbr = errorSpotNbr-1;
            end
            hifiDensities = [...,
                    hifiDensities(1:errorSpotNbr-1),...
                    hifiDensities(errorSpotNbr+1:size(hifiDensities,2))];
            
            % recomputes statistics
            meanDensity = mean(hifiDensities);
            rangeSpots = range(hifiDensities);
            standardDevSpots = std(hifiDensities);
            
            % establish matrix index of maximum density
            [i,maxSpotNbr] = min(hifiDensities);
            if maxSpotNbr >= errorSpotNbr
                maxSpotNbr = maxSpotNbr+1;
            end
            
            % move abnormal spot data
            tempSpots = [];
            tempFault = [];
            tempLines = [];
            if errorSpotNbr > size(hifiDensities,2)
                errorSpotNbr = errorSpotNbr-1;
            end

            for i = 1:errorSpotNbr-1
                tempSpots = [tempSpots,...
                        '\t',num2str(hifiDensities(1,i),'%1.1f')];
                tempFault = [tempFault,...
                        '\t-'];
                tempLines = [tempLines,...
                        '\t20'];
            end
            
            tempSpots = [tempSpots,...
                        '\t-'];
            tempFault = [tempFault,...
                        '\t',num2str(abnormalDensity,'%1.1f')];
            tempLines = [tempLines,...
                        '\t20'];
	
            for i = errorSpotNbr:size(hifiDensities,2)
                tempSpots = [tempSpots,...
                        '\t',num2str(hifiDensities(1,i),'%1.1f')];
                tempFault = [tempFault,...
                        '\t-'];
                tempLines = [tempLines,...
                        '\t20'];
            end
        end

        resultsSpots = [resultsSpots,tempSpots];
		resultsFault = [resultsFault,tempFault];
		resultsLines = [resultsLines,tempLines];
	end
else
    % trap situation where all multi-spots are outside limits (16< >24 lines)
    if sum(multispotDensities) ~= 0
        [i,maxSpotNbr] = min(multispotDensities);
        meanDensity = mean(multispotDensities);
        rangeSpots = range(multispotDensities);
        standardDevSpots = std(multispotDensities);
    else
        meanDensity = '-';
        rangeSpots = '-';
        standardDevSpots = '-';
    end
end

% write results on the figure window
%
% only IF not batch OR batch and set to 'display on' and a max spot detected
if strcmp(imgNature, 'batch images') ~= 1 | ...
        (strcmp(imgNature, 'batch images') == 1 & ...
        get(handles.Varia_BatchDisplay_checkbox,'Value') == 1)
    
    if strcmp(imgNature, 'batch images') ~= 1
        if strcmp(method, 'hifi') == 1
            % shows max density spot
            set(spotAllRectanglesHandles(1,maxSpotNbr),'EdgeColor','red');
            set(spotAllTextHandles(1,maxSpotNbr),'Color','red');
            
            % shows abnormal spots if any
            if errorSpotNbr ~= 0
                set(spotAllRectanglesHandles(1,errorSpotNbr),'EdgeColor','yellow');
                set(spotAllTextHandles(1,errorSpotNbr),'Color','yellow');
            end
        else
            % shows max density spot if any
            if sum(multispotDensities) ~= 0
                set(spotRectangleMaxHandle,'EdgeColor','red');
                set(spotTextMaxHandle,'Color','red');
            end
        end
        
        % write results
        resultsText = [translate('mean'),' = ',num2str(meanDensity,'%11.1f'),' ; ',...
            translate('range'),' = ',num2str(rangeSpots,'%11.1f'),' ; ',...
            translate('standard deviation'),' = ',num2str(standardDevSpots,'%11.2f'),' ; ',...
            translate('slant'),' = ',slant];
        if strcmp(slant, '-') ~= 1
            resultsText = [resultsText,''];
        end
        title(resultsText,'Color','black','FontWeight','normal');
    else
        title(translate('Too few lines per spot.'),...
            'Color','black','FontWeight','normal');        
    end
end

% write results in statistics variable
resultsStats = [...
        '\n',InFileFullNameStr,...
        '\t',num2str(translate(method)),...
        '\t',num2str(meanDensity,'%1.1f'),...
        '\t',num2str(rangeSpots,'%1.1f'),...
        '\t',num2str(standardDevSpots,'%1.2f'),...
        '\t',num2str(nbrOfNormalSpots,'%1.0f'),...
        '\t',slant];

% save results to a file
%
% statistics
resultsFile = fopen(translate('AD751 Results - Statistics.txt'),'at');
fprintf(resultsFile,resultsStats);
fclose(resultsFile);

% spots
resultsFile = fopen(translate('AD751 Results - Spots.txt'),'at');
fprintf(resultsFile,resultsSpots);
fclose(resultsFile);

% lines
resultsFile = fopen(translate('AD751 Results - Lines.txt'),'at');
fprintf(resultsFile,resultsLines);
fclose(resultsFile);

% faulty spots
resultsFile = fopen(translate('AD751 Results - Faults.txt'),'at');
fprintf(resultsFile,resultsFault);
fclose(resultsFile);

% ------------------------------------------------------------
% Pausing between multiple images
if strcmp(imgNature, 'batch images') == 1
    if get(handles.Varia_BatchDisplay_checkbox,'Value') == 1
        if get(handles.Varia_BatchPause_checkbox,'Value') == 1 & ...
            strcmp(get(handles.Varia_BatchPause_checkbox,'Enable'),'on') == 1
            if imgNow ~= size(InNameBatch,1)
                pause;
            end
        end
    else
        % get remaing time
        remainigTime = (etime(clock,startTime)/imgNow)*...
            (numberOfImages-skippedFiles) - etime(clock,startTime);
        remainigTime = round(remainigTime);
        
        % transform in h:m:s
        if remainigTime > 60 & remainigTime < 3600
            remainigTime = [num2str(fix(remainigTime/60)),' min ',...
                    num2str(round(60*rem(remainigTime/60,1))),' sec'];
        elseif remainigTime > 3600
            remainigTime = [num2str(fix(remainigTime/3600)),' h ',...
                    num2str(round(60*rem((remainigTime/3600),1))),' min'];
        else
            remainigTime = [num2str(remainigTime),' sec'];
        end
        
        % increment bar & display remaining time
        waitbar(imgNow/(numberOfImages-skippedFiles),waitbarHandle,...
            [translate('Estimated time left : '),remainigTime]);
        drawnow;
        
        % stop batching if cancel button clicked
        if cancelBatch == 1;
            break
        end
    end
end

% END FILE NAME BATCHING
end
% <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

% Closing AD751 session

% get elapsed time
elapsedTime = round(etime(clock,startTime));

% transform in h:m:s
if elapsedTime >= 60 & elapsedTime < 600
    elapsedTime = ['00h:0',...
            num2str(fix(elapsedTime/60)),'m:',...
            num2str(round(60*rem(elapsedTime/60,1))),'s'];
elseif elapsedTime >= 600 & elapsedTime < 3600
    elapsedTime = ['00h:',...
            num2str(fix(elapsedTime/60)),'m:',...
            num2str(round(60*rem(elapsedTime/60,1))),'s'];
elseif elapsedTime >= 3600
    elapsedMin = round(60*rem((elapsedTime/3600),1));
    if elapsedMin < 10
        elapsedMin = ['0',num2str(elapsedMin)];
    end
    elapsedTime = [num2str(fix(elapsedTime/3600)),'h:',...
            elapsedMin,'m:00s'];
elseif elapsedTime < 10
    elapsedTime = ['00h:00m:0',num2str(elapsedTime),'s'];
else
    elapsedTime = ['00h:00m:',num2str(elapsedTime),'s'];
end

% write settings
% ---
% file
if strcmp(imgNature, 'batch images') == 1
    InFilePathStr = strrep(InFilePath,'\','/');
    resultsSettings = ['\n',InFilePathStr];
else
    resultsSettings = ['\n',InFileFullNameStr];
end
% method
resultsSettings = [resultsSettings,'\t',translate(methodInitial)];
% spot height
if strcmp(methodInitial, 'auto multi-spot') == 1
    resultsSettings = [resultsSettings,'\t',translate('auto')];
else
    spotHeight = round(str2num(get(handles.Method_SpotHeight_edit,'String')));
    resultsSettings = [resultsSettings,'\t',num2str(spotHeight)];
end
% trimming
resultsSettings = [resultsSettings,...
        '\t',num2str(trimTop),...
        '\t',num2str(trimBottom),...
        '\t',num2str(trimLeft),...
        '\t',num2str(trimRight)];
% trim centering
if get(handles.Filters_TrimCentered_checkbox,'Value') == 1
        resultsSettings = [resultsSettings,'\t',translate('on')];
else
        resultsSettings = [resultsSettings,'\t',translate('off')];
end
% axial orientation
if get(handles.Filters_Orient_checkbox,'Value') == 1
        resultsSettings = [resultsSettings,'\t',translate('on')];
else
        resultsSettings = [resultsSettings,'\t',translate('off')];
end
% double emboss
if get(handles.Filters_Emboss_checkbox,'Value') == 1
        resultsSettings = [resultsSettings,'\t',translate('on')];
else
        resultsSettings = [resultsSettings,'\t',translate('off')];
end
% unraster
if get(handles.Filters_Unraster_checkbox,'Value') == 1
        resultsSettings = [resultsSettings,'\t',num2str(cutoffRaster)];
else
        resultsSettings = [resultsSettings,'\t',translate('off')];
end
% scale
resultsSettings = [resultsSettings,'\t',num2str(scale)];
% add 1/2 line
if get(handles.Scale_HalfLine_checkbox,'Value') == 1
        resultsSettings = [resultsSettings,'\t',translate('on')];
else
        resultsSettings = [resultsSettings,'\t',translate('off')];
end
% images and time
endTime = clock;
resultsSettings = [resultsSettings,...
       '\t',num2str(imgNow-skippedFiles),...
       '\t',num2str(numberOfImages-skippedFiles),...
       '\t',num2str(numberOfImages-imgNow),...
       '\t',num2str(datestr(startTime,31)),...
       '\t',num2str(datestr(endTime,31)),...
       '\t',elapsedTime];

% save results (settings) in a file
resultsFile = fopen(translate('AD751 Results - Settings.txt'),'at');
fprintf(resultsFile,resultsSettings);
fclose(resultsFile);
% ---

% if batch, put time-stamp at endings
if strcmp(imgNature, 'batch images') == 1
    timeStamp = ['\n[',translate('End'),...
            ' ',translate('batch'),...
            ' ',num2str(datestr(endTime,31)),']\n'];
    
    % statistics
    resultsFile = fopen(translate('AD751 Results - Statistics.txt'),'at');
    fprintf(resultsFile,timeStamp);
    fclose(resultsFile);
    
    % spots
    resultsFile = fopen(translate('AD751 Results - Spots.txt'),'at');
    fprintf(resultsFile,timeStamp);
    fclose(resultsFile);
    
    % lines
    resultsFile = fopen(translate('AD751 Results - Lines.txt'),'at');
    fprintf(resultsFile,timeStamp);
    fclose(resultsFile);
    
    % faulty spots
    resultsFile = fopen(translate('AD751 Results - Faults.txt'),'at');
    fprintf(resultsFile,timeStamp);
    fclose(resultsFile);
end

% announce end of batch process
if strcmp(imgNature, 'batch images') == 1
    % close waitbar
    if get(handles.Varia_BatchDisplay_checkbox,'Value') == 0
        delete(gcf)
    end
    
    % display text on window
	endBatchText = {[num2str(imgNow-skippedFiles),...
            ' ',translate('images'),...
            ' ',translate('out of'),...
            ' ',num2str(numberOfImages-skippedFiles),...
            ' ',translate('were analysed')],...
            [translate('in'),' ',elapsedTime],...
            translate('and the results saved in the following files:'),...
            [path,'\'],...
            ['   ',translate('AD751 Results - Statistics.txt')],...
            ['   ',translate('AD751 Results - Spots.txt')],...
            ['   ',translate('AD751 Results - Lines.txt')],...
            ['   ',translate('AD751 Results - Faults.txt')],...
            ['   ',translate('AD751 Results - Settings.txt')]};
	warndlg(endBatchText,['AD751: ',translate('Batching complete!')]);
    beep;
end

% ------------------------------------------------------------
function outImg = maskFft(inImg,cutoffRaster)
% cuts a frame to remove high freq rasters
ySize = size(inImg,1);
xSize = size(inImg,2);
% middle
inImg(1:ySize,...
    floor(xSize*(1-cutoffRaster/100)/2):xSize-floor(xSize*(1-cutoffRaster/100)/2)) = ...
    zeros(ySize,xSize-2*floor(xSize*(1-cutoffRaster/100)/2)+1);
% bottom
outImg = inImg(1:floor(ySize*(1-cutoffRaster/100)),:);

% ============================================================
% WAITBAR Cancel button
% ------------------------------------------------------------

function varargout = Waitbar_pushbutton_Callback(hObject, eventdata, handles, varargin)
global cancelBatch;
global waitbarHandle;

% setting cancel flag to 'on'
cancelBatch = 1;

% displaying action acknwoledgment message
waitbar(1,waitbarHandle,[translate('Stopping'),'...']);

% ============================================================
% GUI components
% ------------------------------------------------------------

% Image source
function varargout = File_pushbutton_Callback(hObject, eventdata, handles, varargin)

% get active language
global language BatchList;
language = get(handles.Language_popupmenu,'String');
languageIndex = get(handles.Language_popupmenu,'Value');
language = cell2mat(language(languageIndex));

% select image of allowed file formats
[filename,pathname] = uigetfile(...
   {'*.jpg;*.jpeg;*.tif;*.tiff;*.bmp;*.png;*.pcx;*.hdf;*.xwd', ['> ',translate('Images')]; ...
    '*.txt',        ['> ',translate('List'),' (*.txt)']; ...
    '*.jpg;*.jpeg', 'JPG, JPEG';...
    '*.tif;*.tiff', 'TIFF, TIFF'; ...
    '*.bmp',        'BMP'; ...
    '*.png',        'PNG'; ...
    '*.pcx',        'PCX'; ...
    '*.hdf',        'HDF'; ...
    '*.xwd',        'XWD'; ...
    '*.*',          [translate('All Files'),' (*.*)']}, ...
    ['AD751 - ',translate('Load images')]);

if filename ~= 0 | pathname ~= 0;
    [path,name,ext,ver] = fileparts([pathname,filename]);
    BatchList = [];
    
    % reads list of files if any
    if strcmp(ext,'.txt') == 1
        try
            % reads list
            BatchList = textread(filename,'%s',-1);
        catch
            % error handling    
            errordlg(lasterr,'File Type Error','modal');
            return
        end
        % gets name of first image on the list
        [path,name,ext,ver] = fileparts(char(BatchList(1)));
        filename = [name ext];
        pathname = [path '\'];
    end
    
    % displays first image
    set(handles.Path_text,'String',[pathname,filename]);
    InFileFullName = [pathname,filename];
    cd(pathname);
    
    % memorize old image dimension
    imgHeightOld = size(get(findobj(gca,'Type','image'),'CData'),1);
    imgWidthOld = size(get(findobj(gca,'Type','image'),'CData'),2);
    
    % loads preview image if any
    try
        global ImgPrev
        ImgPrev = imread([pathname,filename]);
    catch
        % error handling    
        errordlg(lasterr,'File Type Error','modal');
        return
    end
    
    % display image
    if get(handles.Varia_Colormap_checkbox,'Value') == 1 &...
            ~isrgb(ImgPrev) & ~isbw(ImgPrev)
        subimage(ImgPrev,jet);
    else
        subimage(ImgPrev);
    end
    set(findobj(gca,'Type','axes'),...
        'ButtonDownFcn','zoom on',...
        'TickDir','out');
    title(filename);
    
    % Trimming area
    trimmingSettings
end
guidata(hObject,handles);

function trimmingSettings
global fig handles ImgPrev
    % Trimming area
    %
    % initialise
    global imgHeight imgWidth cutterTop cutterBottom cutterLeft cutterRight;
    imgHeight = size(ImgPrev,1);
    imgWidth = size(ImgPrev,2);
    
    % get cutter positions
    cutterTopValue = str2num(get(handles.Filters_TrimTop_text,'String'));
    cutterBottomValue = str2num(get(handles.Filters_TrimBottom_text,'String'));
    cutterLeftValue = str2num(get(handles.Filters_TrimLeft_text,'String'));
    cutterRightValue = str2num(get(handles.Filters_TrimRight_text,'String'));
    
    % reset if centered on
    if get(handles.Filters_TrimCentered_checkbox,'Value') == 1
        % calculate center coords
        imgHeightHalf = floor(imgHeight/2);
        imgWidthHalf = floor(imgWidth/2);
        trimRoiHeight = imgHeightOld - cutterTopValue - cutterBottomValue;
        trimRoiWidth = imgWidthOld - cutterLeftValue - cutterRightValue;
        
        % cutter values
        cutterTopValue = imgHeightHalf - floor(trimRoiHeight/2);
        cutterBottomValue = imgHeight - (imgHeightHalf - floor(trimRoiHeight/2) + trimRoiHeight);
        cutterLeftValue = imgWidthHalf - floor(trimRoiWidth/2);
        cutterRightValue = imgWidth - (imgWidthHalf - floor(trimRoiWidth/2) + trimRoiWidth);
        
        % write new values
        set(handles.Filters_TrimTop_text,'String',cutterTopValue);
        set(handles.Filters_TrimBottom_text,'String',cutterBottomValue);
        set(handles.Filters_TrimLeft_text,'String',cutterLeftValue);
        set(handles.Filters_TrimRight_text,'String',cutterRightValue);
    end
    
    % if the cutters touch or overlap then they are set to zero
    if imgHeight - cutterTopValue - cutterBottomValue < 2 | ...
            cutterTopValue < 0 | ...
        cutterBottomValue < 0
        cutterTopValue = 0;
        cutterBottomValue = 0;
        set(handles.Filters_TrimTop_text,'String',cutterTopValue);
        set(handles.Filters_TrimBottom_text,'String',cutterBottomValue);
    end
    if imgWidth - cutterLeftValue - cutterRightValue < 2 | ...
            cutterLeftValue < 0 | ...
        cutterRightValue < 0
        cutterLeftValue = 0;
        cutterRightValue = 0;
        set(handles.Filters_TrimLeft_text,'String',cutterLeftValue);
        set(handles.Filters_TrimRight_text,'String',cutterRightValue);
    end
    
    % display cutters
    cutterTop = line(1:imgWidth,...
        cutterTopValue:cutterTopValue,...
        'LineWidth',5,'Color','red');
    cutterBottom = line(1:imgWidth,...
        imgHeight-cutterBottomValue+1:imgHeight-cutterBottomValue+1,...
        'LineWidth',5,'Color','red');
    cutterLeft = line(cutterLeftValue:cutterLeftValue,...
        1:imgHeight,...
        'LineWidth',5,'Color','red');
    cutterRight = line(imgWidth-cutterRightValue+1:imgWidth-cutterRightValue+1,...
        1:imgHeight,...
        'LineWidth',5,'Color','red');
    
    % hide cutters if no trimming
    if get(handles.Filters_TrimOnOff_checkbox,'Value') == 0
        set(cutterTop,'Visible','off');
        set(cutterBottom,'Visible','off');
        set(cutterLeft,'Visible','off');
        set(cutterRight,'Visible','off');
        set(handles.Filters_TrimTop_text,'Enable','off');
        set(handles.Filters_TrimBottom_text,'Enable','off');
        set(handles.Filters_TrimLeft_text,'Enable','off');
        set(handles.Filters_TrimRight_text,'Enable','off');
        set(handles.Filters_TrimTop_slider,'Enable','off');
        set(handles.Filters_TrimBottom_slider,'Enable','off');
        set(handles.Filters_TrimLeft_slider,'Enable','off');
        set(handles.Filters_TrimRight_slider,'Enable','off');
    end
    
    % set slider data
    set(handles.Filters_TrimTop_slider,...
        'Max',imgHeight,...
        'Value',cutterTopValue,...
        'SliderStep',[1/imgHeight,10/imgHeight]);
    set(handles.Filters_TrimBottom_slider,...
        'Max',imgHeight,...
        'Value',cutterBottomValue,...
        'SliderStep',[1/imgHeight,10/imgHeight]);
    set(handles.Filters_TrimLeft_slider,...
        'Max',imgWidth,...
        'Value',cutterLeftValue,...
        'SliderStep',[1/imgWidth,10/imgWidth]);
    set(handles.Filters_TrimRight_slider,...
        'Max',imgWidth,...
        'Value',cutterRightValue,...
        'SliderStep',[1/imgWidth,10/imgWidth]);
    
    % display spot & image dimensions
    if get(handles.Filters_TrimOnOff_checkbox,'Value') == 0
        xlabel(['[ ',num2str(imgHeight),' \times ',num2str(imgWidth),...
                ' ] ',translate('pixel')]);
    else
        xlabel(['spot [ ',num2str(imgHeight-cutterTopValue-cutterBottomValue),' \times ',...
                num2str(imgWidth-cutterRightValue-cutterLeftValue),' ] \rightarrow '...
                '[ ',num2str(imgHeight),' \times ',num2str(imgWidth),...
                ' ] ',translate('pixel')]);
    end
guidata(fig,handles);

function varargout = Path_text_Callback(hObject, eventdata, handles, varargin)

function varargout = Previz_axes_Callback(hObject, eventdata, handles, varargin)


% Method
function varargout = Method_HiFi_radiobutton_Callback(hObject, eventdata, handles, varargin)
set(handles.Method_Global_radiobutton,'Value',0);
set(handles.Method_MultiSpot_radiobutton,'Value',0);
guidata(hObject,handles);

function varargout = Method_MultiSpot_radiobutton_Callback(hObject, eventdata, handles, varargin)
set(handles.Method_Global_radiobutton,'Value',0);
set(handles.Method_HiFi_radiobutton,'Value',0);
guidata(hObject,handles);

function varargout = Method_SpotHeight_edit_Callback(hObject, eventdata, handles, varargin)

function varargout = Method_SpotHeight_checkbox_Callback(hObject, eventdata, handles, varargin)
if get(handles.Method_SpotHeight_checkbox,'Value') == 0
    set(handles.Method_SpotHeight_legend,'Enable','on');
    set(handles.Method_SpotHeight_edit,'Enable','on');
    set(handles.Method_SpotHeight_text,'Enable','on');
else
    set(handles.Method_SpotHeight_legend,'Enable','off');
    set(handles.Method_SpotHeight_edit,'Enable','off');
    set(handles.Method_SpotHeight_text,'Enable','off');
end
guidata(hObject,handles);

function varargout = Method_Global_radiobutton_Callback(hObject, eventdata, handles, varargin)
set(handles.Method_MultiSpot_radiobutton,'Value',0);
set(handles.Method_HiFi_radiobutton,'Value',0);
guidata(hObject,handles);


% Filtres
function varargout = Filters_TrimOnOff_checkbox_Callback(hObject, eventdata, handles, varargin)
% Toogle centered trim
if get(handles.Filters_TrimOnOff_checkbox,'Value') == 1
    set(handles.Filters_TrimCentered_checkbox,'Enable','on');
else
    set(handles.Filters_TrimCentered_checkbox,'Enable','off');
end
% activate trim only if there is a loaded image
if size(get(handles.Path_text,'String')) ~= 0
	global imgWidth imgHeight cutterTop cutterBottom cutterLeft cutterRight;
	% get cutter positions
	cutterTopValue = str2num(get(handles.Filters_TrimTop_text,'String'));
	cutterBottomValue = str2num(get(handles.Filters_TrimBottom_text,'String'));
	cutterLeftValue = str2num(get(handles.Filters_TrimLeft_text,'String'));
	cutterRightValue = str2num(get(handles.Filters_TrimRight_text,'String'));
	
	if get(handles.Filters_TrimOnOff_checkbox,'Value') == 1
        set(cutterTop,'Visible','on');
        set(cutterBottom,'Visible','on');
        set(cutterLeft,'Visible','on');
        set(cutterRight,'Visible','on');
        set(handles.Filters_TrimTop_text,'Enable','on');
        set(handles.Filters_TrimBottom_text,'Enable','on');
        set(handles.Filters_TrimLeft_text,'Enable','on');
        set(handles.Filters_TrimRight_text,'Enable','on');
        set(handles.Filters_TrimTop_slider,'Enable','on');
        set(handles.Filters_TrimBottom_slider,'Enable','on');
        set(handles.Filters_TrimLeft_slider,'Enable','on');
        set(handles.Filters_TrimRight_slider,'Enable','on');
        % display spot & image dimensions
        xlabel(['spot [ ',num2str(imgHeight-cutterTopValue-cutterBottomValue),' \times ',...
                num2str(imgWidth-cutterRightValue-cutterLeftValue),' ] \rightarrow ',...
                '[ ',num2str(imgHeight),' \times ',num2str(imgWidth),...
                ' ] ',translate('pixel')]);
	else
        set(cutterTop,'Visible','off');
        set(cutterBottom,'Visible','off');
        set(cutterLeft,'Visible','off');
        set(cutterRight,'Visible','off');
        set(handles.Filters_TrimTop_text,'Enable','off');
        set(handles.Filters_TrimBottom_text,'Enable','off');
        set(handles.Filters_TrimLeft_text,'Enable','off');
        set(handles.Filters_TrimRight_text,'Enable','off');
        set(handles.Filters_TrimTop_slider,'Enable','off');
        set(handles.Filters_TrimBottom_slider,'Enable','off');
        set(handles.Filters_TrimLeft_slider,'Enable','off');
        set(handles.Filters_TrimRight_slider,'Enable','off');
        % display image dimensions
        xlabel(['[ ',num2str(imgHeight),' \times ',num2str(imgWidth),...
                ' ] ',translate('pixel')]);
	end
	guidata(hObject,handles);
end
guidata(hObject,handles);

function varargout = Filters_TrimCentered_checkbox_Callback(hObject, eventdata, handles, varargin)
% activate only if there is a loaded image
if size(get(handles.Path_text,'String')) ~= 0
    global imgWidth imgHeight cutterTop cutterBottom cutterLeft cutterRight;
    % get cutter positions
    cutterTopValue = str2num(get(handles.Filters_TrimTop_text,'String'));
    cutterBottomValue = str2num(get(handles.Filters_TrimBottom_text,'String'));
    cutterLeftValue = str2num(get(handles.Filters_TrimLeft_text,'String'));
    cutterRightValue = str2num(get(handles.Filters_TrimRight_text,'String'));
    
    if get(handles.Filters_TrimCentered_checkbox,'Value') == 1
        % calculate center coords
        imgHeightHalf = floor(imgHeight/2);
        imgWidthHalf = floor(imgWidth/2);
        
        % if cutter beyond center put it to the value of the other
        if cutterTopValue >= imgHeightHalf
            cutterTopValue = cutterBottomValue;
        end
        if cutterBottomValue >= imgHeightHalf
            cutterBottomValue = cutterTopValue;
        end
        if cutterLeftValue >= imgWidthHalf
            cutterLeftValue = cutterRightValue;
        end
        if cutterRightValue >= imgWidthHalf
            cutterRightValue = cutterLeftValue;
        end
        
        % set slider data
        set(handles.Filters_TrimTop_slider,...
            'Max',imgHeightHalf,...
            'Value',cutterTopValue,...
            'SliderStep',[1/imgHeightHalf,10/imgHeightHalf]);
        set(handles.Filters_TrimBottom_slider,...
            'Max',imgHeightHalf,...
            'Value',cutterTopValue,...
            'SliderStep',[1/imgHeightHalf,10/imgHeightHalf]);
        set(handles.Filters_TrimLeft_slider,...
            'Max',imgWidthHalf,...
            'Value',cutterLeftValue,...
            'SliderStep',[1/imgWidthHalf,10/imgWidthHalf]);
        set(handles.Filters_TrimRight_slider,...
            'Max',imgWidthHalf,...
            'Value',cutterLeftValue,...
            'SliderStep',[1/imgWidthHalf,10/imgWidthHalf]);
        set(handles.Filters_TrimTop_text,'String',cutterTopValue);
        set(handles.Filters_TrimBottom_text,'String',cutterTopValue);
        set(handles.Filters_TrimLeft_text,'String',cutterLeftValue);
        set(handles.Filters_TrimRight_text,'String',cutterLeftValue);
        
        % set cutter
        set(cutterTop,'YData',[cutterTopValue]);
        set(cutterBottom,'YData',[imgHeight-cutterTopValue+1]);
        set(cutterLeft,'XData',[cutterLeftValue]);
        set(cutterRight,'XData',[imgWidth-cutterLeftValue+1]);
        
    else
        % set slider data
        set(handles.Filters_TrimTop_slider,...
            'Max',imgHeight,...
            'Value',cutterTopValue,...
            'SliderStep',[1/imgHeight,10/imgHeight]);
        set(handles.Filters_TrimBottom_slider,...
            'Max',imgHeight,...
            'Value',cutterBottomValue,...
            'SliderStep',[1/imgHeight,10/imgHeight]);
        set(handles.Filters_TrimLeft_slider,...
            'Max',imgWidth,...
            'Value',cutterLeftValue,...
            'SliderStep',[1/imgWidth,10/imgWidth]);
        set(handles.Filters_TrimRight_slider,...
            'Max',imgWidth,...
            'Value',cutterRightValue,...
            'SliderStep',[1/imgWidth,10/imgWidth]);
        set(handles.Filters_TrimTop_text,'String',cutterTopValue);
        set(handles.Filters_TrimBottom_text,'String',cutterBottomValue);
        set(handles.Filters_TrimLeft_text,'String',cutterLeftValue);
        set(handles.Filters_TrimRight_text,'String',cutterRightValue);
        
        % set cutter
        set(cutterTop,'YData',[cutterTopValue]);
        set(cutterBottom,'YData',[imgHeight-cutterBottomValue+1]);
        set(cutterLeft,'XData',[cutterLeftValue]);
        set(cutterRight,'XData',[imgWidth-cutterRightValue+1]);
        
    end
    guidata(hObject,handles);
end

% Numerical
function varargout = Filters_TrimTop_edit_Callback(hObject, eventdata, handles, varargin)

function varargout = Filters_TrimLeft_edit_Callback(hObject, eventdata, handles, varargin)

function varargout = Filters_TrimBottom_edit_Callback(hObject, eventdata, handles, varargin)

function varargout = Filters_TrimRight_edit_Callback(hObject, eventdata, handles, varargin)
% ---

% -- Slider Top
function varargout = Filters_TrimTop_slider_Callback(hObject, eventdata, handles, varargin)
global imgWidth imgHeight cutterTop cutterBottom;
% get cutter positions
cutterTopValue = round(get(handles.Filters_TrimTop_slider,'Value'));
cutterBottomValue = round(get(handles.Filters_TrimBottom_slider,'Value'));
cutterLeftValue = round(get(handles.Filters_TrimLeft_slider,'Value'));
cutterRightValue = round(get(handles.Filters_TrimRight_slider,'Value'));

% set cutter
if cutterTopValue > imgHeight - cutterBottomValue - 1
    cutterTopValue = imgHeight - cutterBottomValue - 1;
end
set(handles.Filters_TrimTop_text,'String',cutterTopValue);
set(cutterTop,'YData',[cutterTopValue]);

% move other cutter if centered on
if get(handles.Filters_TrimCentered_checkbox,'Value') == 1
    cutterBottomValue = cutterTopValue;
    set(handles.Filters_TrimBottom_slider,'Value',cutterBottomValue);
    set(handles.Filters_TrimBottom_text,'String',cutterBottomValue);
    set(cutterBottom,'YData',[imgHeight-cutterBottomValue+1]);
end

% display spot & image dimensions
xlabel(['spot [ ',num2str(imgHeight-cutterTopValue-cutterBottomValue),' \times ',...
        num2str(imgWidth-cutterRightValue-cutterLeftValue),' ] \rightarrow ',...
        '[ ',num2str(imgHeight),' \times ',num2str(imgWidth),...
        ' ] ',translate('pixel')]);
guidata(hObject,handles);

% -- Slider Bottom
function varargout = Filters_TrimBottom_slider_Callback(hObject, eventdata, handles, varargin)
global imgWidth imgHeight cutterTop cutterBottom;
% get cutter positions
cutterTopValue = round(get(handles.Filters_TrimTop_slider,'Value'));
cutterBottomValue = round(get(handles.Filters_TrimBottom_slider,'Value'));
cutterLeftValue = round(get(handles.Filters_TrimLeft_slider,'Value'));
cutterRightValue = round(get(handles.Filters_TrimRight_slider,'Value'));

% set cutter
if imgHeight - cutterBottomValue < cutterTopValue + 2
    cutterBottomValue = imgHeight - cutterTopValue - 1;
end
set(handles.Filters_TrimBottom_text,'String',cutterBottomValue);
set(cutterBottom,'YData',[imgHeight-cutterBottomValue+1]);

% move other cutter if centered on
if get(handles.Filters_TrimCentered_checkbox,'Value') == 1
    cutterTopValue = cutterBottomValue;
    set(handles.Filters_TrimTop_slider,'Value',cutterTopValue);
    set(handles.Filters_TrimTop_text,'String',cutterTopValue);
    set(cutterTop,'YData',[cutterTopValue]);
end

% display spot & image dimensions
xlabel(['spot [ ',num2str(imgHeight-cutterTopValue-cutterBottomValue),' \times ',...
        num2str(imgWidth-cutterRightValue-cutterLeftValue),' ] \rightarrow ',...
        '[ ',num2str(imgHeight),' \times ',num2str(imgWidth),...
        ' ] ',translate('pixel')]);
guidata(hObject,handles);

% -- Slider Left
function varargout = Filters_TrimLeft_slider_Callback(hObject, eventdata, handles, varargin)
global imgWidth imgHeight cutterLeft cutterRight;
% get cutter positions
cutterTopValue = round(get(handles.Filters_TrimTop_slider,'Value'));
cutterBottomValue = round(get(handles.Filters_TrimBottom_slider,'Value'));
cutterLeftValue = round(get(handles.Filters_TrimLeft_slider,'Value'));
cutterRightValue = round(get(handles.Filters_TrimRight_slider,'Value'));

% set cutter
if cutterLeftValue > imgWidth - cutterRightValue - 1
    cutterLeftValue = imgWidth - cutterRightValue - 1;
end
set(handles.Filters_TrimLeft_text,'String',cutterLeftValue);
set(cutterLeft,'XData',[cutterLeftValue]);

% move other cutter if centered on
if get(handles.Filters_TrimCentered_checkbox,'Value') == 1
    cutterRightValue = cutterLeftValue;
    set(handles.Filters_TrimRight_slider,'Value',cutterRightValue);
    set(handles.Filters_TrimRight_text,'String',cutterRightValue);
    set(cutterRight,'XData',[imgWidth-cutterRightValue+1]);
end

% display spot & image dimensions
xlabel(['spot [ ',num2str(imgHeight-cutterTopValue-cutterBottomValue),' \times ',...
        num2str(imgWidth-cutterRightValue-cutterLeftValue),' ] \rightarrow ',...
        '[ ',num2str(imgHeight),' \times ',num2str(imgWidth),...
        ' ] ',translate('pixel')]);
guidata(hObject,handles);

% -- Slider Right
function varargout = Filters_TrimRight_slider_Callback(hObject, eventdata, handles, varargin)
global imgWidth imgHeight cutterLeft cutterRight;
% get cutter positions
cutterTopValue = round(get(handles.Filters_TrimTop_slider,'Value'));
cutterBottomValue = round(get(handles.Filters_TrimBottom_slider,'Value'));
cutterLeftValue = round(get(handles.Filters_TrimLeft_slider,'Value'));
cutterRightValue = round(get(handles.Filters_TrimRight_slider,'Value'));

% set cutter
if imgWidth - cutterRightValue < cutterLeftValue + 2
    cutterRightValue = imgWidth - cutterLeftValue - 1;
end
set(handles.Filters_TrimRight_text,'String',cutterRightValue);
set(cutterRight,'XData',[imgWidth-cutterRightValue+1]);

% move other cutter if centered on
if get(handles.Filters_TrimCentered_checkbox,'Value') == 1
    cutterLeftValue = cutterRightValue;
    set(handles.Filters_TrimLeft_slider,'Value',cutterLeftValue);
    set(handles.Filters_TrimLeft_text,'String',cutterLeftValue);
    set(cutterLeft,'XData',[cutterLeftValue]);
end

% display spot & image dimensions
xlabel(['spot [ ',num2str(imgHeight-cutterTopValue-cutterBottomValue),' \times ',...
        num2str(imgWidth-cutterRightValue-cutterLeftValue),' ] \rightarrow ',...
        '[ ',num2str(imgHeight),' \times ',num2str(imgWidth),...
        ' ] ',translate('pixel')]);
guidata(hObject,handles);
% ---

function varargout = Filters_Orient_checkbox_Callback(hObject, eventdata, handles, varargin)
if get(handles.Filters_Orient_checkbox,'Value') == 1
    set(handles.Filters_OrientShow_checkbox,'Enable','on');
else
    set(handles.Filters_OrientShow_checkbox,'Enable','off');
end
guidata(hObject,handles);

function varargout = Filters_OrientShow_checkbox_Callback(hObject, eventdata, handles, varargin)

function varargout = Filters_Emboss_checkbox_Callback(hObject, eventdata, handles, varargin)

function varargout = Filters_Unraster_checkbox_Callback(hObject, eventdata, handles, varargin)

function varargout = Filters_Unraster_edit_Callback(hObject, eventdata, handles, varargin)
userEntry = str2double(get(handles.Filters_Unraster_edit,'String'));
if isnan(userEntry) | userEntry <= 0 | userEntry >= 100
    errordlg('You must enter a numeric value between 0 & 100','Bad Input','modal')
end
set(handles.Filters_Unraster_edit,'String','30');
guidata(hObject,handles);

% Scale
function varargout = Scale_contact_radiobutton_Callback(hObject, eventdata, handles, varargin)
set(handles.Scale_dpi_edit,'Enable','on');
set(handles.Scale_rescaled_radiobutton,'Value',0);
% calculates from dpi the equivalent pixel number (1 inch = 25.4 mm)
dpi = str2double(get(handles.Scale_dpi_edit,'String'));
set(handles.Scale_edit,'String',25.4/dpi);
guidata(hObject,handles);

function varargout = Scale_dpi_Callback(hObject, eventdata, handles, varargin)
set(handles.Scale_dpi_edit,'Enable','on');
set(handles.Scale_contact_radiobutton,'Value',1);
set(handles.Scale_rescaled_radiobutton,'Value',0);
% calculates from dpi the equivalent pixel number (1 inch = 25.4 mm)
dpi = str2double(get(handles.Scale_dpi_edit,'String'));
set(handles.Scale_edit,'String',25.4/dpi);
guidata(hObject,handles);

function varargout = Scale_rescaled_radiobutton_Callback(hObject, eventdata, handles, varargin)
set(handles.Scale_contact_radiobutton,'Value',0);
set(handles.Scale_dpi_edit,'Enable','off');
guidata(hObject,handles);

function varargout = Scale_edit_Callback(hObject, eventdata, handles, varargin)
set(handles.Scale_contact_radiobutton,'Value',0);
set(handles.Scale_dpi_edit,'Enable','off');
set(handles.Scale_rescaled_radiobutton,'Value',1);
guidata(hObject,handles);

function varargout = Scale_HalfLine_checkbox_Callback(hObject, eventdata, handles, varargin)


% Varia
function varargout = Varia_Colormap_checkbox_Callback(hObject, eventdata, handles, varargin)
if isempty(get(handles.Path_text,'String')) ~= 1
    global ImgPrev
    if get(handles.Varia_Colormap_checkbox,'Value') == 1 &...
            ~isrgb(ImgPrev)
%         % grayscale adjust
%         subimage(imadjust(histeq(ImgPrev),stretchlim(histeq(ImgPrev)),[]))
        % pseudo-colors
        subimage(ImgPrev,jet)
    else
        subimage(ImgPrev)
    end
    % redraw the trimming's settings
    trimmingSettings
    guidata(hObject,handles);
end

function varargout = Language_popupmenu_Callback(hObject, eventdata, handles, varargin)
global language;
language = get(handles.Language_popupmenu,'String');
languageIndex = get(handles.Language_popupmenu,'Value');
language = cell2mat(language(languageIndex));
dictionnary(language);
guidata(hObject,handles);

function varargout = Varia_BatchOn_checkbox_Callback(hObject, eventdata, handles, varargin)

function varargout = Varia_BatchDisplay_checkbox_Callback(hObject, eventdata, handles, varargin)
if get(handles.Varia_BatchDisplay_checkbox,'Value') == 0
    set(handles.Varia_BatchPause_checkbox,'Enable','off');
else
    set(handles.Varia_BatchPause_checkbox,'Enable','on');
end
guidata(hObject,handles);

function varargout = Varia_BatchPause_checkbox_Callback(hObject, eventdata, handles, varargin)

function varargout = Varia_CloseWindows_pushbutton_Callback(hObject, eventdata, handles, varargin)
figureHandles = get(0,'Children');
figureHandles = figureHandles(2:size(figureHandles,1),1);
close(figureHandles);


% Command buttons
function varargout = Help_pushbutton_Callback(hObject, eventdata, handles, varargin)
web(['file:' which('ad751/help.html')],'-browser');

function varargout = About_pushbutton_Callback(hObject, eventdata, handles, varargin)
aboutText = {...
        translate('AD751 calculates the density of even spaced'),...
        translate('parallel horizontal lines in an image'),...
        ' ',...
        '* * *',...
        ' ',...
        translate('The program was written by:'),...
        ' ',...
        'Vlad ATANASIU & Multimedia Press',...
        'atanasiu@excite.com',...
        'mywebpage.netscape.com/atanasiuvlad/ad751',...
        ' ',...
        translate('Special thanks to:'),...
        ' ',...
        'Ezio Ornato, CNRS',...
        'Jean-Marie Nicolas, ENST',...
        ' ',...
        'v1.13 - 11/10/2003',...
        ' '};
helpdlgHandle = helpdlg(aboutText,'AD751');
helpdlgButtonhandle = findobj(helpdlgHandle,'String','OK');
set(helpdlgButtonhandle,'CallBack','beep;delete(get(0,''CurrentFigure''));');
guidata(hObject,handles);



% ------------------------------------------------------------
% DICTIONNARY
% ------------------------------------------------------------

function out = dictionnary(language)
% Dictionnary for strings on figure in AD751

switch language
case 'Deutsch'
    set(findobj(gcf,'Tag','Parameters_figure'),'Name','AD751: Parameters');

    set(findobj(gcf,'Tag','File_pushbutton'),'String','Bild aufladen');
    set(findobj(gcf,'Tag','Varia_CloseWindows_pushbutton'),'String','Fenster schliesen');
    set(findobj(gcf,'Tag','Help_pushbutton'),'String','Hilfe');
    set(findobj(gcf,'Tag','About_pushbutton'),'String','Version');
    set(findobj(gcf,'Tag','analyse_pushbutton'),'String','Analysieren');
    
    set(findobj(gcf,'Tag','Method_text'),'String','Methode');
    set(findobj(gcf,'Tag','Method_HiFi_radiobutton'),'String','Hifi Meung');
    set(findobj(gcf,'Tag','Method_MultiSpot_radiobutton'),'String','Multi-spot Meung');
    set(findobj(gcf,'Tag','Method_Global_radiobutton'),'String','Globale Meung');
    set(findobj(gcf,'Tag','Method_SpotHeight_checkbox'),'String','Auto Hhe');
    set(findobj(gcf,'Tag','Method_SpotHeight_legend'),'String','Hhe');
    
    set(findobj(gcf,'Tag','Filters_text'),'String','Filter');
    set(findobj(gcf,'Tag','Filters_TrimOnOff_checkbox'),'String','Rnder schneiden');
    set(findobj(gcf,'Tag','Filters_TrimCentered_checkbox'),'String','Zentrieren');
    set(findobj(gcf,'Tag','Filters_Orient_checkbox'),'String','Bildaufrichtung');
    set(findobj(gcf,'Tag','Filters_OrientShow_checkbox'),'String','Zeigen');
    set(findobj(gcf,'Tag','Filters_Emboss_checkbox'),'String','Doppelrelief');
    set(findobj(gcf,'Tag','Filters_Unraster_checkbox'),'String','Derasterisierung');
    
    set(findobj(gcf,'Tag','Scale_text'),'String','Mastab');
    set(findobj(gcf,'Tag','Scale_contact_radiobutton'),'String','1:1 Reproduktion');
    set(findobj(gcf,'Tag','Scale_HalfLine_checkbox'),'String','+ 1/2 Linie');
    set(findobj(gcf,'Tag','Scale_rescaled_radiobutton'),'String','Beliebiger Mastab');
    
    set(findobj(gcf,'Tag','Varia_text'),'String','Varia');
    set(findobj(gcf,'Tag','Varia_Colormap_checkbox'),'String','Jet Farben');
    set(findobj(gcf,'Tag','Varia_BatchOn_checkbox'),'String','Batch');
    set(findobj(gcf,'Tag','Varia_BatchDisplay_checkbox'),'String','Zeigen');
    set(findobj(gcf,'Tag','Varia_BatchPause_checkbox'),'String','Pause');
    
case 'English'
    set(findobj(gcf,'Tag','Parameters_figure'),'Name','AD751: Parameters');

    set(findobj(gcf,'Tag','File_pushbutton'),'String','Load image');
    set(findobj(gcf,'Tag','Varia_CloseWindows_pushbutton'),'String','Close windows');
    set(findobj(gcf,'Tag','Help_pushbutton'),'String','Help');
    set(findobj(gcf,'Tag','About_pushbutton'),'String','About');
    set(findobj(gcf,'Tag','analyse_pushbutton'),'String','Analyse');
    
    set(findobj(gcf,'Tag','Method_text'),'String','Method');
    set(findobj(gcf,'Tag','Method_HiFi_radiobutton'),'String','Hi-fi measure');
    set(findobj(gcf,'Tag','Method_MultiSpot_radiobutton'),'String','Multi-spot measure');
    set(findobj(gcf,'Tag','Method_Global_radiobutton'),'String','Global measure');
    set(findobj(gcf,'Tag','Method_SpotHeight_checkbox'),'String','Auto height');
    set(findobj(gcf,'Tag','Method_SpotHeight_legend'),'String','Height');
    
    set(findobj(gcf,'Tag','Filters_text'),'String','Filters');
    set(findobj(gcf,'Tag','Filters_TrimOnOff_checkbox'),'String','Trim borders');
    set(findobj(gcf,'Tag','Filters_TrimCentered_checkbox'),'String','Centered');
    set(findobj(gcf,'Tag','Filters_Orient_checkbox'),'String','Axial orientation');
    set(findobj(gcf,'Tag','Filters_OrientShow_checkbox'),'String','Show');
    set(findobj(gcf,'Tag','Filters_Emboss_checkbox'),'String','Double emboss');
    set(findobj(gcf,'Tag','Filters_Unraster_checkbox'),'String','Unraster');
    
    set(findobj(gcf,'Tag','Scale_text'),'String','Scale');
    set(findobj(gcf,'Tag','Scale_contact_radiobutton'),'String','1 : 1 reproduction');
    set(findobj(gcf,'Tag','Scale_HalfLine_checkbox'),'String','Add 1/2 line');
    set(findobj(gcf,'Tag','Scale_rescaled_radiobutton'),'String','Rescaled image');
    
    set(findobj(gcf,'Tag','Varia_text'),'String','Varia');
    set(findobj(gcf,'Tag','Varia_Colormap_checkbox'),'String','Jet colormap');
    set(findobj(gcf,'Tag','Varia_BatchOn_checkbox'),'String','Batch');
    set(findobj(gcf,'Tag','Varia_BatchDisplay_checkbox'),'String','Show');
    set(findobj(gcf,'Tag','Varia_BatchPause_checkbox'),'String','Pause');
    
case 'Franais'
    set(findobj(gcf,'Tag','Parameters_figure'),'Name','AD751: Parametres');

    set(findobj(gcf,'Tag','File_pushbutton'),'String','Charger l''image');
    set(findobj(gcf,'Tag','Varia_CloseWindows_pushbutton'),'String','Fermer les fenetres');
    set(findobj(gcf,'Tag','Help_pushbutton'),'String','Aide');
    set(findobj(gcf,'Tag','About_pushbutton'),'String','Version');
    set(findobj(gcf,'Tag','analyse_pushbutton'),'String','Analyser');
    
    set(findobj(gcf,'Tag','Method_text'),'String','Methode');
    set(findobj(gcf,'Tag','Method_HiFi_radiobutton'),'String','Mesure hi-fi');
    set(findobj(gcf,'Tag','Method_MultiSpot_radiobutton'),'String','Mesure multi-spot');
    set(findobj(gcf,'Tag','Method_Global_radiobutton'),'String','Mesure globale');
    set(findobj(gcf,'Tag','Method_SpotHeight_checkbox'),'String','Hauteur auto');
    set(findobj(gcf,'Tag','Method_SpotHeight_legend'),'String','Heuteur');
    
    set(findobj(gcf,'Tag','Filters_text'),'String','Filtres');
    set(findobj(gcf,'Tag','Filters_TrimOnOff_checkbox'),'String','Couper les marges');
    set(findobj(gcf,'Tag','Filters_TrimCentered_checkbox'),'String','Centrer');
    set(findobj(gcf,'Tag','Filters_Orient_checkbox'),'String','Redressement axial');
    set(findobj(gcf,'Tag','Filters_OrientShow_checkbox'),'String','Montrer');
    set(findobj(gcf,'Tag','Filters_Emboss_checkbox'),'String','Double estampage');
    set(findobj(gcf,'Tag','Filters_Unraster_checkbox'),'String','Detramage');
    
    set(findobj(gcf,'Tag','Scale_text'),'String','Echelle');
    set(findobj(gcf,'Tag','Scale_contact_radiobutton'),'String','Reproduction 1:1');
    set(findobj(gcf,'Tag','Scale_HalfLine_checkbox'),'String','+ 1/2 ligne');
    set(findobj(gcf,'Tag','Scale_rescaled_radiobutton'),'String','Reproduction non 1:1');
    
    set(findobj(gcf,'Tag','Varia_text'),'String','Varia');
    set(findobj(gcf,'Tag','Varia_Colormap_checkbox'),'String','Couleurs Jet');
    set(findobj(gcf,'Tag','Varia_BatchOn_checkbox'),'String','Sries');
    set(findobj(gcf,'Tag','Varia_BatchDisplay_checkbox'),'String','Montrer');
    set(findobj(gcf,'Tag','Varia_BatchPause_checkbox'),'String','Pause');
    
case 'Italiano'
    set(findobj(gcf,'Tag','Parameters_figure'),'Name','AD751: Parametri');

    set(findobj(gcf,'Tag','File_pushbutton'),'String','Caricare immagini');
    set(findobj(gcf,'Tag','Varia_CloseWindows_pushbutton'),'String','Chiusura finestre');
    set(findobj(gcf,'Tag','Help_pushbutton'),'String','Aiuto');
    set(findobj(gcf,'Tag','About_pushbutton'),'String','Versione');
    set(findobj(gcf,'Tag','analyse_pushbutton'),'String','Analizzare');
    
    set(findobj(gcf,'Tag','Method_text'),'String','Metodo');
    set(findobj(gcf,'Tag','Method_HiFi_radiobutton'),'String','Misura hi-fi');
    set(findobj(gcf,'Tag','Method_MultiSpot_radiobutton'),'String','Misura multi-spot');
    set(findobj(gcf,'Tag','Method_Global_radiobutton'),'String','Misura globale');
    set(findobj(gcf,'Tag','Method_SpotHeight_checkbox'),'String','Altezza auto');
    set(findobj(gcf,'Tag','Method_SpotHeight_legend'),'String','Altezza');
    
    set(findobj(gcf,'Tag','Filters_text'),'String','Filtri');
    set(findobj(gcf,'Tag','Filters_TrimOnOff_checkbox'),'String','Rifilare i bordi');
    set(findobj(gcf,'Tag','Filters_TrimCentered_checkbox'),'String','Centrare');
    set(findobj(gcf,'Tag','Filters_Orient_checkbox'),'String','Orientamento assiale');
    set(findobj(gcf,'Tag','Filters_OrientShow_checkbox'),'String','Mostra');
    set(findobj(gcf,'Tag','Filters_Emboss_checkbox'),'String','Effetto di bassorilievo');
    set(findobj(gcf,'Tag','Filters_Unraster_checkbox'),'String','Detramaggio');
    
    set(findobj(gcf,'Tag','Scale_text'),'String','Scala');
    set(findobj(gcf,'Tag','Scale_contact_radiobutton'),'String','Copia a contatto');
    set(findobj(gcf,'Tag','Scale_HalfLine_checkbox'),'String','+ 1/2 linea');
    set(findobj(gcf,'Tag','Scale_rescaled_radiobutton'),'String','Immagine non 1:1');
    
    set(findobj(gcf,'Tag','Varia_text'),'String','Varia');
    set(findobj(gcf,'Tag','Varia_Colormap_checkbox'),'String','Colori Jet');
    set(findobj(gcf,'Tag','Varia_BatchOn_checkbox'),'String','Serie');
    set(findobj(gcf,'Tag','Varia_BatchDisplay_checkbox'),'String','Mostra');
    set(findobj(gcf,'Tag','Varia_BatchPause_checkbox'),'String','Pausa');
    
case 'Nederlands'
    set(findobj(gcf,'Tag','Parameters_figure'),'Name','AD751: Parameters');

    set(findobj(gcf,'Tag','File_pushbutton'),'String','Laad afbeelding');
    set(findobj(gcf,'Tag','Varia_CloseWindows_pushbutton'),'String','Venster afsluiten');
    set(findobj(gcf,'Tag','Help_pushbutton'),'String','Help');
    set(findobj(gcf,'Tag','About_pushbutton'),'String','Versie');
    set(findobj(gcf,'Tag','analyse_pushbutton'),'String','Analyseren');
    
    set(findobj(gcf,'Tag','Method_text'),'String','Methode');
    set(findobj(gcf,'Tag','Method_HiFi_radiobutton'),'String','Hifi meting');
    set(findobj(gcf,'Tag','Method_MultiSpot_radiobutton'),'String','Multi-spot meting');
    set(findobj(gcf,'Tag','Method_Global_radiobutton'),'String','Globale meting');
    set(findobj(gcf,'Tag','Method_SpotHeight_checkbox'),'String','Auto hoogte');
    set(findobj(gcf,'Tag','Method_SpotHeight_legend'),'String','hoogte');
    
    set(findobj(gcf,'Tag','Filters_text'),'String','Filter');
    set(findobj(gcf,'Tag','Filters_TrimOnOff_checkbox'),'String','Randen afsnijden');
    set(findobj(gcf,'Tag','Filters_TrimCentered_checkbox'),'String','Centreren');
    set(findobj(gcf,'Tag','Filters_Orient_checkbox'),'String','Axiale orientatie');
    set(findobj(gcf,'Tag','Filters_OrientShow_checkbox'),'String','Laten zien');
    set(findobj(gcf,'Tag','Filters_Emboss_checkbox'),'String','Dubbelrelief');
    set(findobj(gcf,'Tag','Filters_Unraster_checkbox'),'String','Derasterisatie');
    
    set(findobj(gcf,'Tag','Scale_text'),'String','Schaal');
    set(findobj(gcf,'Tag','Scale_contact_radiobutton'),'String','1:1 reproductie');
    set(findobj(gcf,'Tag','Scale_HalfLine_checkbox'),'String','+ 1/2 lijn');
    set(findobj(gcf,'Tag','Scale_rescaled_radiobutton'),'String','Opnieuw inschalen');
    
    set(findobj(gcf,'Tag','Varia_text'),'String','Varia');
    set(findobj(gcf,'Tag','Varia_Colormap_checkbox'),'String','Jet colormap');
    set(findobj(gcf,'Tag','Varia_BatchOn_checkbox'),'String','Groep');
    set(findobj(gcf,'Tag','Varia_BatchDisplay_checkbox'),'String','Laat zien');
    set(findobj(gcf,'Tag','Varia_BatchPause_checkbox'),'String','Pause');
end

% Dictionnary for variables in AD751
function out = translate(word)
global handles;
language = get(handles.Language_popupmenu,'String');
languageIndex = get(handles.Language_popupmenu,'Value');
language = cell2mat(language(languageIndex));

switch language
case 'English'
    out = word;
case 'Franais'
    switch word
	case 'AD751 calculates the density of even spaced'
		out = 'AD751 decompte la densit des lignes';
	case 'AD751 Results - Faults.txt'
		out = 'AD751 Resultats - Fautes.txt';
	case 'AD751 Results - Lines.txt'
		out = 'AD751 Resultats - Lignes.txt';
	case 'AD751 Results - Settings.txt'
		out = 'AD751 Resultats - Proprites.txt';
	case 'AD751 Results - Statistics.txt'
		out = 'AD751 Resultats - Statistiques.txt';
	case 'AD751 Results - Spots.txt'
		out = 'AD751 Resultats - Spots.txt';
	case 'All Files'
		out = 'Tous les fichiers';
	case 'and the results saved in the following files:'
		out = 'et les resultats sauves dans les fichiers suivants:';
	case 'Analysis'
		out = 'Analyse';
	case 'Analysing multiple images'
		out = 'Analyse d''une srie d''images';
	case 'auto'
		out = 'auto';
	case 'after'
		out = 'aprs';
	case 'auto multi-spot'
		out = 'multi-spot auto';
	case 'Axial orientation'
		out = 'Redressement axial';
	case 'batch'
		out = 'sries';
	case 'Batching complete!'
		out = 'Fin de l''analyse!';
	case 'Cancel'
		out = 'Annuler';
	case 'Centered'
		out = 'Centrer';
	case 'counts parallel even spaced lines on a image'
		out = 'decompte des lignes paralleles quidistantes';
	case 'density [mm]'
		out = 'densit [mm]';
	case 'Double emboss'
		out = 'Double estampage';
	case 'Drink coffee - the machine is working...'
		out = 'Buvez du pastis - la machine travaille...';
	case 'End'
		out = 'Fin';
	case 'Estimated time left : '
		out = 'Temps restant prvu : ';
	case 'even spaced lines found with hifi method.'
		out = 'lignes quidistantes trouves avec la methode hifi.';
	case 'File'
		out = 'Fichier';
	case 'file'
		out = 'fichier';
	case 'Fourier transform'
		out = 'Transformation Fourier';
	case 'global'
		out = 'globale';
	case 'Height'
		out = 'Hauteur';
	case 'hifi'
		out = 'hifi';
	case 'Images'
		out = 'Images';
	case 'images'
		out = 'images';
	case 'image emboss'
		out = 'estampage de l''image';
	case 'Image lists'
		out = 'Liste d''image';
	case 'Images processed'
		out = 'Images traites';
	case 'in'
		out = 'en';
	case 'infered from spots with not between'
		out = 'extrapol de spots avec autre qu''entre';
	case 'Input image'
		out = 'Image d''entre';
	case 'lines'
		out = 'lignes';
	case 'List'
		out = 'Liste';
	case 'Load images'
		out = 'Charger les images';
	case 'Lower y-axis'
		out = 'Axe Y infrieure';
	case 'manual multi-spot'
		out = 'multi-spot manuel';
	case 'mean'
        out = 'moyenne';
	case 'Method'
        out = 'Methode';
	case 'method'
        out = 'methode';
    case 'No'
		out = 'Pas de';
    case 'non-aberrant spots'
		out = 'spots non-aberrants';
	case 'off'
		out = 'non';
	case 'on'
		out = 'oui';
	case 'out of'
		out = 'sur';
	case 'parallel horizontal lines in an image'
		out = 'paralelles horizontales dans une image';
	case 'periods / image (noise: '
		out = 'priodes / image (bruit: ';
	case 'pixel'
		out = 'pixel';
	case 'Please wait...'
		out = 'Patientez SVP...';
	case 'power'
		out = 'magnitude';
	case 'range'
		out = 'tendue';
	case 'Remaining'
		out = 'Restantes';
	case 'Scale'
		out = 'chelle';
	case 'scale'
		out = 'chelle';
	case 'slant'
		out = 'inclinaison';
	case 'Special thanks to:'
		out = 'Remerciements particuliers  :';
	case 'spot'
		out = 'spot';
	case 'standard deviation'
		out = 'cart type';
	case 'Start'
		out = 'Debut';
	case 'Stopping'
		out = 'Arrt';
	case 'The program was written by:'
		out = 'Le programme a t ecrit par :';
	case 'Too few lines per spot.'
		out = 'Trop peu de lignes par spot.';
	case 'Total'
		out = 'Total';
	case 'Trim top'
		out = 'Coupe haut';
	case 'Trim bottom'
		out = 'Coupe bas';
	case 'Trim left'
		out = 'Coupe gauche';
	case 'Trim right'
		out = 'Coupe droite';
	case 'Unraster'
		out = 'Detramage';
	case 'unraster cutoff'
		out = 'limite du detramage';
	case 'were analysed'
		out = 'ont t analyses';
    case 'X-axis sideview'
		out = 'Vue laterale axe X';
    end
case 'Deutsch'
    a=1;
    switch word
	case 'AD751 calculates the density of even spaced'
		out = 'AD751 ermittelt die Dichte von gleich entfernte';
	case 'AD751 Results - Faults.txt'
		out = 'AD751 Resultats - Fehler.txt';
	case 'AD751 Results - Lines.txt'
		out = 'AD751 Ergebnisse - Linien.txt';
	case 'AD751 Results - Settings.txt'
		out = 'AD751 Resultats - Einstellungen.txt';
	case 'AD751 Results - Statistics.txt'
		out = 'AD751 Resultats - Statistiken.txt';
	case 'AD751 Results - Spots.txt'
		out = 'AD751 Ergebnisse - Spots.txt';
	case 'All Files'
		out = 'Alle Dateien';
	case 'and the results saved in the following files:'
		out = 'und die Ergebnisse in folgenede Dateien gespeichert:';
	case 'Analysis'
		out = 'Analyse';
	case 'Analysing multiple images'
		out = 'Analyse mehreren Bilder';
	case 'after'
		out = 'nach';
	case 'auto'
		out = 'auto';
	case 'auto multi-spot'
		out = 'auto multi-spot';
	case 'Axial orientation'
		out = 'Axiale orientation';
	case 'batch'
		out = 'Batch';
	case 'Batching complete!'
		out = 'Ende der Analyse!';
	case 'Cancel'
		out = 'Abbrechen';
	case 'Centered'
		out = 'Zentriert';
	case 'counts parallel even spaced lines on a image'
		out = 'ermittelt paralele equidistante Linien auf ein Bild';
	case 'density [mm]'
		out = 'Dichte [mm]';
	case 'Double emboss'
		out = 'Doppelrelief';
	case 'Drink coffee - the machine is working...'
		out = 'Trinken Sie Mangosaft - die Maschine arbeitet...';
	case 'End'
		out = 'Ende';
	case 'Estimated time left : '
		out = 'Eingeschzte bleibende Zeit: ';
	case 'even spaced lines found with hifi method.'
		out = 'equidistante Linien mit die hifi Methode gefunden.';
	case 'File'
		out = 'Datei';
	case 'file'
		out = 'Datei';
	case 'Fourier transform'
		out = 'Fourier Transformation';
	case 'global'
		out = 'global';
	case 'Height'
		out = 'Hhe';
	case 'hifi'
		out = 'Hifi';
	case 'Images'
		out = 'Bilder';
	case 'images'
		out = 'Bilder';
	case 'image emboss'
		out = 'Reliefbild';
	case 'Image lists'
		out = 'Bilder Liste';
	case 'Images processed'
		out = 'Bilder verarbeitet';
	case 'images were analysed'
		out = 'Bilder wurden analysiert';
	case 'in'
		out = 'in';
	case 'infered from spots with not between'
		out = 'abgeleitet von Spots mit nicht zwischen';
	case 'Input image'
		out = 'Eingabe Bild';
	case 'lines'
		out = 'Linien';
	case 'List'
		out = 'Liste';
	case 'Load images'
		out = 'Bilder aufladen';
	case 'Lower y-axis'
		out = 'Untere y-Axis';
	case 'manual multi-spot'
		out = 'manuel multi-spot';
	case 'mean'
        out = 'Durchschnitt';
	case 'Method'
        out = 'Methode';
	case 'method'
        out = 'Methode';
	case 'No'
		out = 'Keine';
    case 'non-aberrant spots'
		out = 'nicht aberrante Spots';
	case 'off'
		out = 'nein';
	case 'on'
		out = 'ja';
	case 'out of'
		out = 'aus';
	case 'parallel horizontal lines in an image'
		out = 'paralelle horizontale Linien in ein Bild';
	case 'periods / image (noise: '
		out = 'Perioden / Bild (Strung: ';
	case 'pixel'
		out = 'Pixel';
	case 'Please wait...'
		out = 'Bitten warten...';
	case 'power'
		out = 'Strke';
	case 'range'
		out = 'Bereich';
	case 'Remaining'
		out = 'Verbleiben';
	case 'Scale'
		out = 'Mastab';
	case 'scale'
		out = 'Mastab';
	case 'slant'
		out = 'Neigung';
	case 'Special thanks to:'
		out = 'Spezielle Danksagung:';
	case 'spot'
		out = 'Spot';
	case 'standard deviation'
		out = 'Standardabweichung';
	case 'Start'
		out = 'Anfang';
	case 'Stopping'
		out = 'Beenden';
	case 'The program was written by:'
		out = 'Das Programm wurde geschrieben von:';
	case 'Too few lines per spot.'
		out = 'Zu wenige Linien auf Spot.';
	case 'Total'
		out = 'Total';
	case 'Trim top'
		out = 'Schnitt oben';
	case 'Trim bottom'
		out = 'Schnitt unten';
	case 'Trim left'
		out = 'Schnitt links';
	case 'Trim right'
		out = 'Schnitt rechts';
	case 'Unraster'
		out = 'Derasterisierung';
	case 'unraster cutoff'
		out = 'Derasterisierungs Grenze';
	case 'were analysed'
		out = 'wurden analysiert';
	case 'X-axis sideview'
		out = 'X-Axis Ansicht';
    end
case 'Italiano'
    switch word
	case 'AD751 calculates the density of even spaced'
		out = 'AD751 calcola la densit delle equidistante';
	case 'AD751 Results - Faults.txt'
		out = 'AD751 Risultati - Misure difettose.txt';
	case 'AD751 Results - Lines.txt'
		out = 'AD751 Risultati - Linee.txt';
	case 'AD751 Results - Settings.txt'
		out = 'AD751 Resultats - Propriet.txt';
	case 'AD751 Results - Statistics.txt'
		out = 'AD751 Risultati - Statistiche.txt';
	case 'AD751 Results - Spots.txt'
		out = 'AD751 Risultati - Spots.txt';
	case 'All Files'
		out = 'Tutti i file';
	case 'and the results saved in the following files:'
		out = 'e i risultati sono registrati nei seguenti file:';
	case 'Analysis'
		out = 'Analisi';
	case 'Analysing multiple images'
		out = 'Analizzare immagini multiple';
	case 'after'
		out = 'dopo';
	case 'auto'
		out = 'auto';
	case 'auto multi-spot'
		out = 'auto multi-spot';
	case 'Axial orientation'
		out = 'Orientamento assiale';
	case 'batch'
		out = 'serie';
	case 'Batching complete!'
		out = 'Lotto completo!';
	case 'Cancel'
		out = 'Annullare';
	case 'Centered'
		out = 'Centrare';
	case 'counts parallel even spaced lines on a image'
		out = 'calcola le linea parallele equidistanti';
	case 'density [mm]'
		out = 'densit [mm]';
	case 'Double emboss'
		out = 'Effetto di bassorilievo';
	case 'Drink coffee - the machine is working...'
		out = 'Bevete la aqua minerale - la macchina sta lavorando...';
	case 'End'
		out = 'Fine';
	case 'Estimated time left : '
		out = 'Tempo aproximative restante: ';
	case 'even spaced lines found with hifi method.'
        out = 'linee spaziate regolarmente trovato con il metodo ad alta fedelt.';
	case 'File'
		out = 'File';
	case 'file'
		out = 'file';
	case 'Fourier transform'
		out = 'Trasformata di Fourier';
	case 'global'
		out = 'globale';
	case 'Height'
		out = 'Altezza';
	case 'hifi'
		out = 'alta fedelt';
	case 'Images'
		out = 'Immagini';
	case 'images'
		out = 'immagini';
	case 'image emboss'
		out = 'bassorilievo de l''immagine';
	case 'Image lists'
		out = 'Liste di immagine';
	case 'Images processed'
		out = 'Immagini trattato';
	case 'in'
		out = 'in';
	case 'infered from spots with not between'
		out = 'infered dai punti con non fra';
	case 'Input image'
		out = 'Immagine dell''input';
	case 'lines'
		out = 'linee';
	case 'List'
		out = 'Lista';
	case 'Load images'
		out = 'Caricare le immagini';
	case 'Lower y-axis'
		out = 'Asse Y inferiore';
	case 'manual multi-spot'
		out = 'multi-spot manuale';
	case 'mean'
        out = 'media';
	case 'Method'
        out = 'Methode';
	case 'method'
        out = 'metodo';
	case 'No'
		out = 'Nulle';
    case 'non-aberrant spots'
		out = 'spot non-aberranti';
	case 'off'
		out = 'no';
	case 'on'
		out = 'si';
	case 'out of'
		out = 'da';
	case 'parallel horizontal lines in an image'
		out = 'linee orizzontali in un''immagine';
	case 'periods / image (noise: '
		out = 'periodi / immagine (rumore: ';
	case 'pixel'
		out = 'pixel';
	case 'Please wait...'
		out = 'Attendere, prego ...';
	case 'power'
		out = 'potenza';
	case 'range'
		out = 'intervallo';
	case 'Remaining'
		out = 'Rimanere';
	case 'Scale'
		out = 'Scala';
	case 'scale'
		out = 'scala';
	case 'slant'
		out = 'inclinazione';
	case 'Special thanks to:'
		out = 'Ringraziamenti speciali a :';
	case 'spot'
		out = 'spot';
	case 'standard deviation'
		out = 'scarto tipo';
	case 'Start'
		out = 'Inizio';
	case 'Stopping'
		out = 'Chiudere';
	case 'The program was written by:'
		out = 'Il programma  stato scritto da :';
	case 'Too few lines per spot.'
		out = 'Troppo poche linee per il spot.';
	case 'Total'
		out = 'Totale';
	case 'Trim top'
		out = 'Taglio cima';
	case 'Trim bottom'
		out = 'Taglio basso';
	case 'Trim left'
		out = 'Taglio sinistra';
	case 'Trim right'
		out = 'Taglio destra';
	case 'Unraster'
		out = 'Detramaggio';
	case 'unraster cutoff'
		out = 'limita di detramaggio';
	case 'were analysed'
		out = 'sono state analizzate';
   case 'X-axis sideview'
		out = 'Vista laterale dell''asse X';
    end
case 'Nederlands'
    switch word
	case 'AD751 calculates the density of even spaced'
		out = 'AD751 berekent de dichtheid van regelmatig verdeelde';
	case 'AD751 Results - Faults.txt'
		out = 'AD751 Resultaten - Fouten.txt';
	case 'AD751 Results - Lines.txt'
		out = 'AD751 Resultaten - Lijnen.txt';
	case 'AD751 Results - Settings.txt'
		out = 'AD751 Resultats - Overeenkomst .txt';
	case 'AD751 Results - Statistics.txt'
		out = 'AD751 Resultaten - Statistieken.txt';
	case 'AD751 Results - Spots.txt'
		out = 'AD751 Resultaten - Spots.txt';
	case 'All Files'
		out = 'Alle bestanden';
	case 'and the results saved in the following files:'
		out = 'en de resultaten opgeslagen in de volgende bestanden:';
	case 'Analysis'
		out = 'Analyse';
	case 'Analysing multiple images'
		out = 'Bezig met het analyseren van meerdere afbeeldingen';
	case 'after'
		out = 'naach';
	case 'auto'
		out = 'auto';
	case 'auto multi-spot'
		out = 'auto multi-spot';
	case 'Axial orientation'
		out = 'Axiale orientatie';
	case 'batch'
		out = 'groep';
	case 'Batching complete!'
		out = 'Analyse compleet!';
	case 'Cancel'
		out = 'Annuleren';
	case 'Centered'
		out = 'Centreren';
	case 'counts parallel even spaced lines on a image'
		out = 'telt parallelle, regelmatig verdeelde lijnen op een afbeelding';
	case 'density [mm]'
		out = 'dichtheid [mm]';
	case 'Double emboss'
		out = 'Dubbelrelief';
	case 'Drink coffee - the machine is working...'
		out = 'Drink melk - de computer is bezig...';
	case 'End'
		out = 'Eind';
	case 'Estimated time left : '
		out = 'Geschatte tijd nog te gaan: ';
	case 'even spaced lines found with hifi method.'
		out = 'regelmatig verdeelde lijnen, gevonden met de hifi Methode.';
	case 'File'
		out = 'Bestand';
	case 'file'
		out = 'bestand';
	case 'Fourier transform'
		out = 'Fourier transformatie';
	case 'global'
		out = 'globale';
	case 'Height'
		out = 'Hoogte';
	case 'hifi'
		out = 'hifi';
	case 'Images'
		out = 'Afbeeldingen';
	case 'images'
		out = 'afbeeldingen';
	case 'image emboss'
		out = 'afbeelding relief';
	case 'Image lists'
		out = 'Afbeeldingen lijst';
	case 'Images processed'
		out = 'Afbeeldingen verwerkt';
	case 'in'
		out = 'in';
	case 'infered from spots with not between'
		out = 'afgeleid van spots welke niet liggen tussen';
	case 'Input image'
		out = 'Ingevoerde afbeelding';
	case 'lines'
		out = 'Lijnen';
	case 'List'
		out = 'Lijst';
	case 'Load images'
		out = 'Laad afbeelding';
	case 'Lower y-axis'
		out = 'Onderste y-as';
	case 'manual multi-spot'
		out = 'manuel multi-spot';
	case 'mean'
        out = 'gemiddelde';
	case 'Method'
        out = 'Methode';
	case 'method'
        out = 'methode';
	case 'No'
		out = 'Geen';
    case 'non-aberrant spots'
		out = 'geen afwijkende Spots';
	case 'off'
		out = 'geen';
	case 'on'
		out = 'ja';
	case 'out of'
		out = 'op';
	case 'parallel horizontal lines in an image'
		out = 'parallelle, horizontale Lijnen in een afbeelding';
	case 'periods / image (noise: '
		out = 'periode / afbeelding (storing: ';
	case 'pixel'
		out = 'pixel';
	case 'Please wait...'
		out = 'Even wachten a.u.b....';
	case 'power'
		out = 'sterkte';
	case 'range'
		out = 'bereik';
	case 'Remaining'
		out = 'Overblijven';
	case 'Scale'
		out = 'Schaal';
	case 'scale'
		out = 'schaal';
	case 'slant'
		out = 'helling';
	case 'Special thanks to:'
		out = 'Speciale dank aan:';
	case 'spot'
		out = 'spot';
	case 'standard deviation'
		out = 'standaarddeviatie';
	case 'Start'
		out = 'Begin';
	case 'Stopping'
		out = 'Schut';
	case 'The program was written by:'
		out = 'Het programma is geschreven door:';
	case 'Too few lines per spot.'
		out = 'Te weinig lijnen per spot.';
	case 'Total'
		out = 'Totaal';
	case 'Trim top'
		out = 'Snee top';
	case 'Trim bottom'
		out = 'Snee onderst';
	case 'Trim left'
		out = 'Snee links';
	case 'Trim right'
		out = 'Snee rechts';
 	case 'Unraster'
		out = 'Derasterisatie';
	case 'unraster cutoff'
		out = 'derasterisatie begin';
	case 'were analysed'
		out = 'zijn geanalyseerd';
	case 'X-axis sideview'
		out = 'X-as zijaanzicht';
    end
end


